import typing

from gi.repository import GLib
from gi.repository import GObject
from typing_extensions import Self

T = typing.TypeVar("T")

def bt() -> None: ...
def errno_return() -> ErrorEnum: ...
def error_clear_errno() -> None: ...
def error_crash_here() -> None: ...
def error_get_error_state(error: ErrorEnum) -> ErrorState: ...
def error_perror() -> str: ...
def error_restore(error: str, es: ErrorState) -> None: ...
def error_set_errno(x: ErrorEnum) -> None: ...
def error_set_error_state(error: ErrorEnum, state: ErrorState) -> None: ...
def error_stop_here() -> None: ...
def error_strerror(e: ErrorEnum) -> str: ...
def error_supress(error: str) -> ErrorState: ...
def get_unknown_token_handling_setting() -> Unknowntokenhandling: ...
def memory_add_tmp_buffer(buf: None) -> None: ...
def memory_append_char(ch: int) -> typing.Tuple[list[int], list[int]]: ...
def memory_append_string(str: str) -> typing.Tuple[list[int], list[int]]: ...
def memory_free_buffer(buf: None) -> None: ...
def memory_new_buffer(size: int) -> None: ...
def memory_resize_buffer(buf: None, size: int) -> None: ...
def memory_strdup(s: str) -> str: ...
def memory_tmp_buffer(size: int) -> None: ...
def memory_tmp_copy(str: str) -> str: ...
def mime_parse(
    func: typing.Callable[..., str], *user_data: typing.Any
) -> Component: ...
def recur_expand_recurrence(rule: str, start: int, count: int) -> list[int]: ...
def request_status_code(stat: RequestStatus) -> str: ...
def request_status_desc(stat: RequestStatus) -> str: ...
def request_status_from_num(major: int, minor: int) -> RequestStatus: ...
def request_status_major(stat: RequestStatus) -> int: ...
def request_status_minor(stat: RequestStatus) -> int: ...
def restriction_check(comp: Component) -> int: ...
def restriction_compare(restr: RestrictionKind, count: int) -> int: ...
def set_unknown_token_handling_setting(newSetting: Unknowntokenhandling) -> None: ...

class Array(Object):
    """
    :Constructors:

    ::

        Array(**properties)

    Object ICalArray

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def copy(self) -> Array: ...
    def remove_element_at(self, position: int) -> None: ...
    def size(self) -> int: ...

class ArrayClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ArrayClass()
    """

    parent: ObjectClass = ...

class Attach(Object):
    """
    :Constructors:

    ::

        Attach(**properties)
        new_from_bytes(bytes:GLib.Bytes) -> ICalGLib.Attach
        new_from_data(data:str, free_fn:GLib.Func=None, free_fn_data=None) -> ICalGLib.Attach
        new_from_url(url:str) -> ICalGLib.Attach

    Object ICalAttach

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def get_data(self) -> typing.Optional[str]: ...
    def get_is_url(self) -> bool: ...
    def get_url(self) -> typing.Optional[str]: ...
    @classmethod
    def new_from_bytes(cls, bytes: GLib.Bytes) -> Attach: ...
    @classmethod
    def new_from_data(
        cls,
        data: str,
        free_fn: typing.Optional[typing.Callable[..., None]] = None,
        *free_fn_data: typing.Any,
    ) -> Attach: ...
    @classmethod
    def new_from_url(cls, url: str) -> Attach: ...

class AttachClass(GObject.GPointer):
    """
    :Constructors:

    ::

        AttachClass()
    """

    parent: ObjectClass = ...

class CompIter(Object):
    """
    :Constructors:

    ::

        CompIter(**properties)

    Object ICalCompIter

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def deref(self) -> Component: ...
    def next(self) -> Component: ...
    def prior(self) -> Component: ...

class CompIterClass(GObject.GPointer):
    """
    :Constructors:

    ::

        CompIterClass()
    """

    parent: ObjectClass = ...

class Component(Object):
    """
    :Constructors:

    ::

        Component(**properties)
        new(kind:ICalGLib.ComponentKind) -> ICalGLib.Component
        new_from_string(str:str) -> ICalGLib.Component
        new_vagenda() -> ICalGLib.Component
        new_valarm() -> ICalGLib.Component
        new_vavailability() -> ICalGLib.Component
        new_vcalendar() -> ICalGLib.Component
        new_vevent() -> ICalGLib.Component
        new_vfreebusy() -> ICalGLib.Component
        new_vjournal() -> ICalGLib.Component
        new_vpoll() -> ICalGLib.Component
        new_vquery() -> ICalGLib.Component
        new_vtimezone() -> ICalGLib.Component
        new_vtodo() -> ICalGLib.Component
        new_vvoter() -> ICalGLib.Component
        new_x(x_name:str) -> ICalGLib.Component
        new_xavailable() -> ICalGLib.Component
        new_xdaylight() -> ICalGLib.Component
        new_xstandard() -> ICalGLib.Component
        new_xvote() -> ICalGLib.Component

    Object ICalComponent

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def add_component(self, child: Component) -> None: ...
    def add_property(self, property: Property) -> None: ...
    def as_ical_string(self) -> str: ...
    def begin_component(self, kind: ComponentKind) -> CompIter: ...
    def check_restrictions(self) -> int: ...
    def clone(self) -> Component: ...
    def convert_errors(self) -> None: ...
    def count_components(self, kind: ComponentKind) -> int: ...
    def count_errors(self) -> int: ...
    def count_properties(self, kind: PropertyKind) -> int: ...
    def end_component(self, kind: ComponentKind) -> CompIter: ...
    def foreach_recurrence(
        self,
        start: Time,
        end: Time,
        callback: typing.Optional[typing.Callable[..., None]] = None,
        *user_data: typing.Any,
    ) -> None: ...
    def foreach_tzid(
        self,
        callback: typing.Optional[typing.Callable[..., None]] = None,
        *user_data: typing.Any,
    ) -> None: ...
    def get_comment(self) -> str: ...
    def get_current_component(self) -> Component: ...
    def get_current_property(self) -> Property: ...
    def get_description(self) -> str: ...
    def get_dtend(self) -> Time: ...
    def get_dtstamp(self) -> Time: ...
    def get_dtstart(self) -> Time: ...
    def get_due(self) -> Time: ...
    def get_duration(self) -> Duration: ...
    def get_first_component(
        self, kind: ComponentKind
    ) -> typing.Optional[Component]: ...
    def get_first_property(self, kind: PropertyKind) -> typing.Optional[Property]: ...
    def get_first_real_component(self) -> Component: ...
    def get_inner(self) -> typing.Optional[Component]: ...
    def get_location(self) -> str: ...
    def get_method(self) -> PropertyMethod: ...
    def get_next_component(self, kind: ComponentKind) -> typing.Optional[Component]: ...
    def get_next_property(self, kind: PropertyKind) -> typing.Optional[Property]: ...
    def get_parent(self) -> typing.Optional[Component]: ...
    def get_recurrenceid(self) -> Time: ...
    def get_relcalid(self) -> str: ...
    def get_sequence(self) -> int: ...
    def get_span(self) -> TimeSpan: ...
    def get_status(self) -> PropertyStatus: ...
    def get_summary(self) -> str: ...
    def get_timezone(self, tzid: str) -> typing.Optional[Timezone]: ...
    def get_uid(self) -> str: ...
    def is_valid(self) -> bool: ...
    def isa(self) -> ComponentKind: ...
    def isa_component(self) -> int: ...
    @staticmethod
    def kind_from_string(string: str) -> ComponentKind: ...
    @staticmethod
    def kind_is_valid(kind: ComponentKind) -> bool: ...
    @staticmethod
    def kind_to_string(kind: ComponentKind) -> str: ...
    def merge_component(self, comp_to_merge: Component) -> None: ...
    @classmethod
    def new(cls, kind: ComponentKind) -> Component: ...
    @classmethod
    def new_from_string(cls, str: str) -> Component: ...
    @classmethod
    def new_vagenda(cls) -> Component: ...
    @classmethod
    def new_valarm(cls) -> Component: ...
    @classmethod
    def new_vavailability(cls) -> Component: ...
    @classmethod
    def new_vcalendar(cls) -> Component: ...
    @classmethod
    def new_vevent(cls) -> Component: ...
    @classmethod
    def new_vfreebusy(cls) -> Component: ...
    @classmethod
    def new_vjournal(cls) -> Component: ...
    @classmethod
    def new_vpoll(cls) -> Component: ...
    @classmethod
    def new_vquery(cls) -> Component: ...
    @classmethod
    def new_vtimezone(cls) -> Component: ...
    @classmethod
    def new_vtodo(cls) -> Component: ...
    @classmethod
    def new_vvoter(cls) -> Component: ...
    @classmethod
    def new_x(cls, x_name: str) -> Component: ...
    @classmethod
    def new_xavailable(cls) -> Component: ...
    @classmethod
    def new_xdaylight(cls) -> Component: ...
    @classmethod
    def new_xstandard(cls) -> Component: ...
    @classmethod
    def new_xvote(cls) -> Component: ...
    def remove_component(self, child: Component) -> None: ...
    def remove_property(self, property: Property) -> None: ...
    def set_comment(self, v: str) -> None: ...
    def set_description(self, v: str) -> None: ...
    def set_dtend(self, v: Time) -> None: ...
    def set_dtstamp(self, v: Time) -> None: ...
    def set_dtstart(self, v: Time) -> None: ...
    def set_due(self, v: Time) -> None: ...
    def set_duration(self, v: Duration) -> None: ...
    def set_location(self, v: str) -> None: ...
    def set_method(self, method: PropertyMethod) -> None: ...
    def set_parent(self, parent: typing.Optional[Component] = None) -> None: ...
    def set_recurrenceid(self, v: Time) -> None: ...
    def set_relcalid(self, v: str) -> None: ...
    def set_sequence(self, v: int) -> None: ...
    def set_status(self, status: PropertyStatus) -> None: ...
    def set_summary(self, v: str) -> None: ...
    def set_uid(self, v: str) -> None: ...
    def strip_errors(self) -> None: ...

class ComponentClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ComponentClass()
    """

    parent: ObjectClass = ...

class Datetimeperiod(Object):
    """
    :Constructors:

    ::

        Datetimeperiod(**properties)
        new() -> ICalGLib.Datetimeperiod

    Object ICalDatetimeperiod

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def get_period(self) -> Period: ...
    def get_time(self) -> Time: ...
    @classmethod
    def new(cls) -> Datetimeperiod: ...
    def set_period(self, period: Period) -> None: ...
    def set_time(self, time: Time) -> None: ...

class DatetimeperiodClass(GObject.GPointer):
    """
    :Constructors:

    ::

        DatetimeperiodClass()
    """

    parent: ObjectClass = ...

class Duration(Object):
    """
    :Constructors:

    ::

        Duration(**properties)
        new_bad_duration() -> ICalGLib.Duration
        new_from_int(t:int) -> ICalGLib.Duration
        new_from_string(str:str) -> ICalGLib.Duration
        new_null_duration() -> ICalGLib.Duration

    Object ICalDuration

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def as_ical_string(self) -> str: ...
    def as_int(self) -> int: ...
    def get_days(self) -> int: ...
    def get_hours(self) -> int: ...
    def get_minutes(self) -> int: ...
    def get_seconds(self) -> int: ...
    def get_weeks(self) -> int: ...
    def is_bad_duration(self) -> bool: ...
    def is_neg(self) -> bool: ...
    def is_null_duration(self) -> bool: ...
    @classmethod
    def new_bad_duration(cls) -> Duration: ...
    @classmethod
    def new_from_int(cls, t: int) -> Duration: ...
    @classmethod
    def new_from_string(cls, str: str) -> Duration: ...
    @classmethod
    def new_null_duration(cls) -> Duration: ...
    def set_days(self, days: int) -> None: ...
    def set_hours(self, hours: int) -> None: ...
    def set_is_neg(self, is_neg: bool) -> None: ...
    def set_minutes(self, minutes: int) -> None: ...
    def set_seconds(self, seconds: int) -> None: ...
    def set_weeks(self, weeks: int) -> None: ...

class DurationClass(GObject.GPointer):
    """
    :Constructors:

    ::

        DurationClass()
    """

    parent: ObjectClass = ...

class Geo(Object):
    """
    :Constructors:

    ::

        Geo(**properties)
        new(lat:float, lon:float) -> ICalGLib.Geo

    Object ICalGeo

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def clone(self) -> Geo: ...
    def get_lat(self) -> float: ...
    def get_lon(self) -> float: ...
    @classmethod
    def new(cls, lat: float, lon: float) -> Geo: ...
    def set_lat(self, lat: float) -> None: ...
    def set_lon(self, lon: float) -> None: ...

class GeoClass(GObject.GPointer):
    """
    :Constructors:

    ::

        GeoClass()
    """

    parent: ObjectClass = ...

class Object(GObject.Object):
    """
    :Constructors:

    ::

        Object(**properties)

    Object ICalObject

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(GObject.Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    parent: GObject.Object = ...
    priv: ObjectPrivate = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def add_depender(self, depender: GObject.Object) -> None: ...
    @staticmethod
    def free_global_objects() -> None: ...
    def get_always_destroy(self) -> bool: ...
    def get_is_global_memory(self) -> bool: ...
    def ref_owner(self) -> typing.Optional[GObject.Object]: ...
    def remove_depender(self, depender: GObject.Object) -> None: ...
    def remove_owner(self) -> None: ...
    def set_always_destroy(self, value: bool) -> None: ...
    def set_native_destroy_func(
        self, native_destroy_func: typing.Callable[[None], None]
    ) -> None: ...
    def set_owner(self, owner: GObject.Object) -> None: ...
    def steal_native(self) -> None: ...

class ObjectClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ObjectClass()
    """

    parent_class: GObject.ObjectClass = ...

class ObjectPrivate(GObject.GPointer): ...

class Parameter(Object):
    """
    :Constructors:

    ::

        Parameter(**properties)
        new(v:ICalGLib.ParameterKind) -> ICalGLib.Parameter
        new_actionparam(v:ICalGLib.ParameterAction) -> ICalGLib.Parameter
        new_altrep(v:str) -> ICalGLib.Parameter
        new_charset(v:str) -> ICalGLib.Parameter
        new_cn(v:str) -> ICalGLib.Parameter
        new_cutype(v:ICalGLib.ParameterCutype) -> ICalGLib.Parameter
        new_delegatedfrom(v:str) -> ICalGLib.Parameter
        new_delegatedto(v:str) -> ICalGLib.Parameter
        new_dir(v:str) -> ICalGLib.Parameter
        new_display(value:ICalGLib.ParameterDisplay) -> ICalGLib.Parameter
        new_email(value:str) -> ICalGLib.Parameter
        new_enable(v:ICalGLib.ParameterEnable) -> ICalGLib.Parameter
        new_encoding(v:ICalGLib.ParameterEncoding) -> ICalGLib.Parameter
        new_fbtype(v:ICalGLib.ParameterFbtype) -> ICalGLib.Parameter
        new_feature(value:ICalGLib.ParameterFeature) -> ICalGLib.Parameter
        new_filename(v:str) -> ICalGLib.Parameter
        new_fmttype(v:str) -> ICalGLib.Parameter
        new_from_string(value:str) -> ICalGLib.Parameter
        new_from_value_string(kind:ICalGLib.ParameterKind, value:str) -> ICalGLib.Parameter
        new_iana(v:str) -> ICalGLib.Parameter
        new_id(v:str) -> ICalGLib.Parameter
        new_label(value:str) -> ICalGLib.Parameter
        new_language(v:str) -> ICalGLib.Parameter
        new_latency(v:str) -> ICalGLib.Parameter
        new_local(v:ICalGLib.ParameterLocal) -> ICalGLib.Parameter
        new_localize(v:str) -> ICalGLib.Parameter
        new_managedid(v:str) -> ICalGLib.Parameter
        new_member(v:str) -> ICalGLib.Parameter
        new_modified(v:str) -> ICalGLib.Parameter
        new_options(v:str) -> ICalGLib.Parameter
        new_partstat(v:ICalGLib.ParameterPartstat) -> ICalGLib.Parameter
        new_patchaction(value:ICalGLib.ParameterPatchaction) -> ICalGLib.Parameter
        new_publiccomment(v:str) -> ICalGLib.Parameter
        new_range(v:ICalGLib.ParameterRange) -> ICalGLib.Parameter
        new_reason(v:str) -> ICalGLib.Parameter
        new_related(v:ICalGLib.ParameterRelated) -> ICalGLib.Parameter
        new_reltype(v:ICalGLib.ParameterReltype) -> ICalGLib.Parameter
        new_required(v:ICalGLib.ParameterRequired) -> ICalGLib.Parameter
        new_response(v:int) -> ICalGLib.Parameter
        new_role(v:ICalGLib.ParameterRole) -> ICalGLib.Parameter
        new_rsvp(v:ICalGLib.ParameterRsvp) -> ICalGLib.Parameter
        new_scheduleagent(v:ICalGLib.ParameterScheduleagent) -> ICalGLib.Parameter
        new_scheduleforcesend(v:ICalGLib.ParameterScheduleforcesend) -> ICalGLib.Parameter
        new_schedulestatus(v:str) -> ICalGLib.Parameter
        new_sentby(v:str) -> ICalGLib.Parameter
        new_size(v:str) -> ICalGLib.Parameter
        new_stayinformed(v:ICalGLib.ParameterStayinformed) -> ICalGLib.Parameter
        new_substate(v:ICalGLib.ParameterSubstate) -> ICalGLib.Parameter
        new_tzid(v:str) -> ICalGLib.Parameter
        new_value(v:ICalGLib.ParameterValue) -> ICalGLib.Parameter
        new_x(v:str) -> ICalGLib.Parameter
        new_xliccomparetype(v:ICalGLib.ParameterXliccomparetype) -> ICalGLib.Parameter
        new_xlicerrortype(v:ICalGLib.ParameterXlicerrortype) -> ICalGLib.Parameter

    Object ICalParameter

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def as_ical_string(self) -> str: ...
    def clone(self) -> Parameter: ...
    def get_actionparam(self) -> ParameterAction: ...
    def get_altrep(self) -> typing.Optional[str]: ...
    def get_charset(self) -> typing.Optional[str]: ...
    def get_cn(self) -> typing.Optional[str]: ...
    def get_cutype(self) -> typing.Optional[ParameterCutype]: ...
    def get_delegatedfrom(self) -> typing.Optional[str]: ...
    def get_delegatedto(self) -> typing.Optional[str]: ...
    def get_dir(self) -> typing.Optional[str]: ...
    def get_display(self) -> ParameterDisplay: ...
    def get_email(self) -> typing.Optional[str]: ...
    def get_enable(self) -> ParameterEnable: ...
    def get_encoding(self) -> ParameterEncoding: ...
    def get_fbtype(self) -> ParameterFbtype: ...
    def get_feature(self) -> ParameterFeature: ...
    def get_filename(self) -> typing.Optional[str]: ...
    def get_fmttype(self) -> typing.Optional[str]: ...
    def get_iana(self) -> typing.Optional[str]: ...
    def get_iana_name(self) -> typing.Optional[str]: ...
    def get_iana_value(self) -> typing.Optional[str]: ...
    def get_id(self) -> typing.Optional[str]: ...
    def get_label(self) -> typing.Optional[str]: ...
    def get_language(self) -> typing.Optional[str]: ...
    def get_latency(self) -> typing.Optional[str]: ...
    def get_local(self) -> ParameterLocal: ...
    def get_localize(self) -> typing.Optional[str]: ...
    def get_managedid(self) -> typing.Optional[str]: ...
    def get_member(self) -> typing.Optional[str]: ...
    def get_modified(self) -> typing.Optional[str]: ...
    def get_options(self) -> typing.Optional[str]: ...
    def get_parent(self) -> typing.Optional[Property]: ...
    def get_partstat(self) -> ParameterPartstat: ...
    def get_patchaction(self) -> ParameterPatchaction: ...
    def get_publiccomment(self) -> typing.Optional[str]: ...
    def get_range(self) -> ParameterRange: ...
    def get_reason(self) -> typing.Optional[str]: ...
    def get_related(self) -> ParameterRelated: ...
    def get_reltype(self) -> ParameterReltype: ...
    def get_required(self) -> ParameterRequired: ...
    def get_response(self) -> int: ...
    def get_role(self) -> ParameterRole: ...
    def get_rsvp(self) -> ParameterRsvp: ...
    def get_scheduleagent(self) -> ParameterScheduleagent: ...
    def get_scheduleforcesend(self) -> ParameterScheduleforcesend: ...
    def get_schedulestatus(self) -> typing.Optional[str]: ...
    def get_sentby(self) -> typing.Optional[str]: ...
    def get_size(self) -> typing.Optional[str]: ...
    def get_stayinformed(self) -> ParameterStayinformed: ...
    def get_substate(self) -> ParameterSubstate: ...
    def get_tzid(self) -> typing.Optional[str]: ...
    def get_value(self) -> ParameterValue: ...
    def get_x(self) -> typing.Optional[str]: ...
    def get_xliccomparetype(self) -> ParameterXliccomparetype: ...
    def get_xlicerrortype(self) -> ParameterXlicerrortype: ...
    def get_xname(self) -> typing.Optional[str]: ...
    def get_xvalue(self) -> typing.Optional[str]: ...
    def has_same_name(self, param2: Parameter) -> int: ...
    def isa(self) -> ParameterKind: ...
    def isa_parameter(self) -> int: ...
    @staticmethod
    def kind_from_string(string: str) -> ParameterKind: ...
    @staticmethod
    def kind_is_valid(kind: ParameterKind) -> bool: ...
    @staticmethod
    def kind_to_string(kind: ParameterKind) -> str: ...
    @classmethod
    def new(cls, v: ParameterKind) -> Parameter: ...
    @classmethod
    def new_actionparam(cls, v: ParameterAction) -> Parameter: ...
    @classmethod
    def new_altrep(cls, v: str) -> Parameter: ...
    @classmethod
    def new_charset(cls, v: str) -> Parameter: ...
    @classmethod
    def new_cn(cls, v: str) -> Parameter: ...
    @classmethod
    def new_cutype(cls, v: ParameterCutype) -> Parameter: ...
    @classmethod
    def new_delegatedfrom(cls, v: str) -> Parameter: ...
    @classmethod
    def new_delegatedto(cls, v: str) -> Parameter: ...
    @classmethod
    def new_dir(cls, v: str) -> Parameter: ...
    @classmethod
    def new_display(cls, value: ParameterDisplay) -> Parameter: ...
    @classmethod
    def new_email(cls, value: str) -> Parameter: ...
    @classmethod
    def new_enable(cls, v: ParameterEnable) -> Parameter: ...
    @classmethod
    def new_encoding(cls, v: ParameterEncoding) -> Parameter: ...
    @classmethod
    def new_fbtype(cls, v: ParameterFbtype) -> Parameter: ...
    @classmethod
    def new_feature(cls, value: ParameterFeature) -> Parameter: ...
    @classmethod
    def new_filename(cls, v: str) -> Parameter: ...
    @classmethod
    def new_fmttype(cls, v: str) -> Parameter: ...
    @classmethod
    def new_from_string(cls, value: str) -> Parameter: ...
    @classmethod
    def new_from_value_string(cls, kind: ParameterKind, value: str) -> Parameter: ...
    @classmethod
    def new_iana(cls, v: str) -> Parameter: ...
    @classmethod
    def new_id(cls, v: str) -> Parameter: ...
    @classmethod
    def new_label(cls, value: str) -> Parameter: ...
    @classmethod
    def new_language(cls, v: str) -> Parameter: ...
    @classmethod
    def new_latency(cls, v: str) -> Parameter: ...
    @classmethod
    def new_local(cls, v: ParameterLocal) -> Parameter: ...
    @classmethod
    def new_localize(cls, v: str) -> Parameter: ...
    @classmethod
    def new_managedid(cls, v: str) -> Parameter: ...
    @classmethod
    def new_member(cls, v: str) -> Parameter: ...
    @classmethod
    def new_modified(cls, v: str) -> Parameter: ...
    @classmethod
    def new_options(cls, v: str) -> Parameter: ...
    @classmethod
    def new_partstat(cls, v: ParameterPartstat) -> Parameter: ...
    @classmethod
    def new_patchaction(cls, value: ParameterPatchaction) -> Parameter: ...
    @classmethod
    def new_publiccomment(cls, v: str) -> Parameter: ...
    @classmethod
    def new_range(cls, v: ParameterRange) -> Parameter: ...
    @classmethod
    def new_reason(cls, v: str) -> Parameter: ...
    @classmethod
    def new_related(cls, v: ParameterRelated) -> Parameter: ...
    @classmethod
    def new_reltype(cls, v: ParameterReltype) -> Parameter: ...
    @classmethod
    def new_required(cls, v: ParameterRequired) -> Parameter: ...
    @classmethod
    def new_response(cls, v: int) -> Parameter: ...
    @classmethod
    def new_role(cls, v: ParameterRole) -> Parameter: ...
    @classmethod
    def new_rsvp(cls, v: ParameterRsvp) -> Parameter: ...
    @classmethod
    def new_scheduleagent(cls, v: ParameterScheduleagent) -> Parameter: ...
    @classmethod
    def new_scheduleforcesend(cls, v: ParameterScheduleforcesend) -> Parameter: ...
    @classmethod
    def new_schedulestatus(cls, v: str) -> Parameter: ...
    @classmethod
    def new_sentby(cls, v: str) -> Parameter: ...
    @classmethod
    def new_size(cls, v: str) -> Parameter: ...
    @classmethod
    def new_stayinformed(cls, v: ParameterStayinformed) -> Parameter: ...
    @classmethod
    def new_substate(cls, v: ParameterSubstate) -> Parameter: ...
    @classmethod
    def new_tzid(cls, v: str) -> Parameter: ...
    @classmethod
    def new_value(cls, v: ParameterValue) -> Parameter: ...
    @classmethod
    def new_x(cls, v: str) -> Parameter: ...
    @classmethod
    def new_xliccomparetype(cls, v: ParameterXliccomparetype) -> Parameter: ...
    @classmethod
    def new_xlicerrortype(cls, v: ParameterXlicerrortype) -> Parameter: ...
    def set_actionparam(self, v: ParameterAction) -> None: ...
    def set_altrep(self, v: str) -> None: ...
    def set_charset(self, v: str) -> None: ...
    def set_cn(self, v: str) -> None: ...
    def set_cutype(self, v: ParameterCutype) -> None: ...
    def set_delegatedfrom(self, v: str) -> None: ...
    def set_delegatedto(self, v: str) -> None: ...
    def set_dir(self, v: str) -> None: ...
    def set_display(self, value: ParameterDisplay) -> None: ...
    def set_email(self, value: str) -> None: ...
    def set_enable(self, v: ParameterEnable) -> None: ...
    def set_encoding(self, v: ParameterEncoding) -> None: ...
    def set_fbtype(self, v: ParameterFbtype) -> None: ...
    def set_feature(self, value: ParameterFeature) -> None: ...
    def set_filename(self, v: str) -> None: ...
    def set_fmttype(self, v: str) -> None: ...
    def set_iana(self, v: str) -> None: ...
    def set_iana_name(self, v: str) -> None: ...
    def set_iana_value(self, v: str) -> None: ...
    def set_id(self, v: str) -> None: ...
    def set_label(self, value: str) -> None: ...
    def set_language(self, v: str) -> None: ...
    def set_latency(self, v: str) -> None: ...
    def set_local(self, v: ParameterLocal) -> None: ...
    def set_localize(self, v: str) -> None: ...
    def set_managedid(self, v: str) -> None: ...
    def set_member(self, v: str) -> None: ...
    def set_modified(self, v: str) -> None: ...
    def set_options(self, v: str) -> None: ...
    def set_parent(self, property: typing.Optional[Property] = None) -> None: ...
    def set_partstat(self, v: ParameterPartstat) -> None: ...
    def set_patchaction(self, value: ParameterPatchaction) -> None: ...
    def set_publiccomment(self, v: str) -> None: ...
    def set_range(self, v: ParameterRange) -> None: ...
    def set_reason(self, v: str) -> None: ...
    def set_related(self, v: ParameterRelated) -> None: ...
    def set_reltype(self, v: ParameterReltype) -> None: ...
    def set_required(self, v: ParameterRequired) -> None: ...
    def set_response(self, v: int) -> None: ...
    def set_role(self, v: ParameterRole) -> None: ...
    def set_rsvp(self, v: ParameterRsvp) -> None: ...
    def set_scheduleagent(self, v: ParameterScheduleagent) -> None: ...
    def set_scheduleforcesend(self, v: ParameterScheduleforcesend) -> None: ...
    def set_schedulestatus(self, v: str) -> None: ...
    def set_sentby(self, v: str) -> None: ...
    def set_size(self, v: str) -> None: ...
    def set_stayinformed(self, v: ParameterStayinformed) -> None: ...
    def set_substate(self, v: ParameterSubstate) -> None: ...
    def set_tzid(self, v: str) -> None: ...
    def set_value(self, v: ParameterValue) -> None: ...
    def set_x(self, v: str) -> None: ...
    def set_xliccomparetype(self, v: ParameterXliccomparetype) -> None: ...
    def set_xlicerrortype(self, v: ParameterXlicerrortype) -> None: ...
    def set_xname(self, v: str) -> None: ...
    def set_xvalue(self, v: str) -> None: ...
    @staticmethod
    def value_to_value_kind(value: ParameterValue) -> ValueKind: ...

class ParameterClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ParameterClass()
    """

    parent: ObjectClass = ...

class Parser(Object):
    """
    :Constructors:

    ::

        Parser(**properties)
        new() -> ICalGLib.Parser

    Object ICalParser

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def add_line(
        self, str: typing.Optional[str] = None
    ) -> typing.Optional[Component]: ...
    def clean(self) -> typing.Optional[Component]: ...
    def free(self) -> None: ...
    def get_line(
        self, func: typing.Callable[..., str], *user_data: typing.Any
    ) -> str: ...
    def get_state(self) -> ParserState: ...
    @classmethod
    def new(cls) -> Parser: ...
    def parse(
        self, func: typing.Callable[..., str], *user_data: typing.Any
    ) -> Component: ...
    @staticmethod
    def parse_string(str: str) -> Component: ...

class ParserClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ParserClass()
    """

    parent: ObjectClass = ...

class Period(Object):
    """
    :Constructors:

    ::

        Period(**properties)
        new_from_string(str:str) -> ICalGLib.Period
        new_null_period() -> ICalGLib.Period

    Object ICalPeriod

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def as_ical_string(self) -> str: ...
    def get_duration(self) -> Duration: ...
    def get_end(self) -> Time: ...
    def get_start(self) -> Time: ...
    def is_null_period(self) -> bool: ...
    def is_valid_period(self) -> bool: ...
    @classmethod
    def new_from_string(cls, str: str) -> Period: ...
    @classmethod
    def new_null_period(cls) -> Period: ...
    def set_duration(self, duration: Duration) -> None: ...
    def set_end(self, end: Time) -> None: ...
    def set_start(self, start: Time) -> None: ...

class PeriodClass(GObject.GPointer):
    """
    :Constructors:

    ::

        PeriodClass()
    """

    parent: ObjectClass = ...

class Property(Object):
    """
    :Constructors:

    ::

        Property(**properties)
        new(kind:ICalGLib.PropertyKind) -> ICalGLib.Property
        new_acceptresponse(v:str) -> ICalGLib.Property
        new_acknowledged(v:ICalGLib.Time) -> ICalGLib.Property
        new_action(v:ICalGLib.PropertyAction) -> ICalGLib.Property
        new_allowconflict(v:str) -> ICalGLib.Property
        new_attach(v:ICalGLib.Attach) -> ICalGLib.Property
        new_attendee(v:str) -> ICalGLib.Property
        new_busytype(v:ICalGLib.PropertyBusytype) -> ICalGLib.Property
        new_calid(v:str) -> ICalGLib.Property
        new_calmaster(v:str) -> ICalGLib.Property
        new_calscale(v:str) -> ICalGLib.Property
        new_capversion(v:str) -> ICalGLib.Property
        new_carid(v:str) -> ICalGLib.Property
        new_carlevel(v:ICalGLib.PropertyCarlevel) -> ICalGLib.Property
        new_categories(v:str) -> ICalGLib.Property
        new_class(v:ICalGLib.Property_Class) -> ICalGLib.Property
        new_cmd(v:ICalGLib.PropertyCmd) -> ICalGLib.Property
        new_color(v:str) -> ICalGLib.Property
        new_comment(v:str) -> ICalGLib.Property
        new_completed(v:ICalGLib.Time) -> ICalGLib.Property
        new_components(v:str) -> ICalGLib.Property
        new_contact(v:str) -> ICalGLib.Property
        new_created(v:ICalGLib.Time) -> ICalGLib.Property
        new_csid(v:str) -> ICalGLib.Property
        new_datemax(v:ICalGLib.Time) -> ICalGLib.Property
        new_datemin(v:ICalGLib.Time) -> ICalGLib.Property
        new_decreed(v:str) -> ICalGLib.Property
        new_defaultcharset(v:str) -> ICalGLib.Property
        new_defaultlocale(v:str) -> ICalGLib.Property
        new_defaulttzid(v:str) -> ICalGLib.Property
        new_defaultvcars(v:str) -> ICalGLib.Property
        new_deny(v:str) -> ICalGLib.Property
        new_description(v:str) -> ICalGLib.Property
        new_dtend(v:ICalGLib.Time) -> ICalGLib.Property
        new_dtstamp(v:ICalGLib.Time) -> ICalGLib.Property
        new_dtstart(v:ICalGLib.Time) -> ICalGLib.Property
        new_due(v:ICalGLib.Time) -> ICalGLib.Property
        new_duration(v:ICalGLib.Duration) -> ICalGLib.Property
        new_estimatedduration(v:ICalGLib.Duration) -> ICalGLib.Property
        new_exdate(v:ICalGLib.Time) -> ICalGLib.Property
        new_expand(v:int) -> ICalGLib.Property
        new_exrule(v:ICalGLib.Recurrence) -> ICalGLib.Property
        new_freebusy(v:ICalGLib.Period) -> ICalGLib.Property
        new_from_string(str:str) -> ICalGLib.Property
        new_geo(v:ICalGLib.Geo) -> ICalGLib.Property
        new_grant(v:str) -> ICalGLib.Property
        new_itipversion(v:str) -> ICalGLib.Property
        new_lastmodified(v:ICalGLib.Time) -> ICalGLib.Property
        new_location(v:str) -> ICalGLib.Property
        new_maxcomponentsize(v:int) -> ICalGLib.Property
        new_maxdate(v:ICalGLib.Time) -> ICalGLib.Property
        new_maxresults(v:int) -> ICalGLib.Property
        new_maxresultssize(v:int) -> ICalGLib.Property
        new_method(v:ICalGLib.PropertyMethod) -> ICalGLib.Property
        new_mindate(v:ICalGLib.Time) -> ICalGLib.Property
        new_multipart(v:str) -> ICalGLib.Property
        new_name(v:str) -> ICalGLib.Property
        new_organizer(v:str) -> ICalGLib.Property
        new_owner(v:str) -> ICalGLib.Property
        new_percentcomplete(v:int) -> ICalGLib.Property
        new_permission(v:str) -> ICalGLib.Property
        new_pollcompletion(v:ICalGLib.PropertyPollcompletion) -> ICalGLib.Property
        new_pollitemid(v:int) -> ICalGLib.Property
        new_pollmode(v:ICalGLib.PropertyPollmode) -> ICalGLib.Property
        new_pollproperties(v:str) -> ICalGLib.Property
        new_pollwinner(v:int) -> ICalGLib.Property
        new_priority(v:int) -> ICalGLib.Property
        new_prodid(v:str) -> ICalGLib.Property
        new_query(v:str) -> ICalGLib.Property
        new_queryid(v:str) -> ICalGLib.Property
        new_querylevel(v:ICalGLib.PropertyQuerylevel) -> ICalGLib.Property
        new_queryname(v:str) -> ICalGLib.Property
        new_rdate(v:ICalGLib.Datetimeperiod) -> ICalGLib.Property
        new_recuraccepted(v:str) -> ICalGLib.Property
        new_recurexpand(v:str) -> ICalGLib.Property
        new_recurlimit(v:str) -> ICalGLib.Property
        new_recurrenceid(v:ICalGLib.Time) -> ICalGLib.Property
        new_relatedto(v:str) -> ICalGLib.Property
        new_relcalid(v:str) -> ICalGLib.Property
        new_repeat(v:int) -> ICalGLib.Property
        new_replyurl(v:str) -> ICalGLib.Property
        new_requeststatus(v:ICalGLib.Reqstat) -> ICalGLib.Property
        new_resources(v:str) -> ICalGLib.Property
        new_response(v:int) -> ICalGLib.Property
        new_restriction(v:str) -> ICalGLib.Property
        new_rrule(v:ICalGLib.Recurrence) -> ICalGLib.Property
        new_scope(v:str) -> ICalGLib.Property
        new_sequence(v:int) -> ICalGLib.Property
        new_status(v:ICalGLib.PropertyStatus) -> ICalGLib.Property
        new_storesexpanded(v:str) -> ICalGLib.Property
        new_summary(v:str) -> ICalGLib.Property
        new_target(v:str) -> ICalGLib.Property
        new_taskmode(v:ICalGLib.PropertyTaskmode) -> ICalGLib.Property
        new_transp(v:ICalGLib.PropertyTransp) -> ICalGLib.Property
        new_trigger(v:ICalGLib.Trigger) -> ICalGLib.Property
        new_tzid(v:str) -> ICalGLib.Property
        new_tzidaliasof(v:str) -> ICalGLib.Property
        new_tzname(v:str) -> ICalGLib.Property
        new_tzoffsetfrom(v:int) -> ICalGLib.Property
        new_tzoffsetto(v:int) -> ICalGLib.Property
        new_tzuntil(v:ICalGLib.Time) -> ICalGLib.Property
        new_tzurl(v:str) -> ICalGLib.Property
        new_uid(v:str) -> ICalGLib.Property
        new_url(v:str) -> ICalGLib.Property
        new_version(v:str) -> ICalGLib.Property
        new_voter(v:str) -> ICalGLib.Property
        new_x(v:str) -> ICalGLib.Property
        new_xlicclass(v:ICalGLib.PropertyXlicclass) -> ICalGLib.Property
        new_xlicclustercount(v:str) -> ICalGLib.Property
        new_xlicerror(v:str) -> ICalGLib.Property
        new_xlicmimecharset(v:str) -> ICalGLib.Property
        new_xlicmimecid(v:str) -> ICalGLib.Property
        new_xlicmimecontenttype(v:str) -> ICalGLib.Property
        new_xlicmimeencoding(v:str) -> ICalGLib.Property
        new_xlicmimefilename(v:str) -> ICalGLib.Property
        new_xlicmimeoptinfo(v:str) -> ICalGLib.Property

    Object ICalProperty

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def add_parameter(self, parameter: Parameter) -> None: ...
    def as_ical_string(self) -> str: ...
    def clone(self) -> Property: ...
    def count_parameters(self) -> int: ...
    @staticmethod
    def enum_to_string(e: int) -> str: ...
    def get_acceptresponse(self) -> str: ...
    def get_acknowledged(self) -> Time: ...
    def get_action(self) -> PropertyAction: ...
    def get_allowconflict(self) -> str: ...
    def get_attach(self) -> Attach: ...
    def get_attendee(self) -> str: ...
    def get_busytype(self) -> PropertyBusytype: ...
    def get_calid(self) -> str: ...
    def get_calmaster(self) -> str: ...
    def get_calscale(self) -> str: ...
    def get_capversion(self) -> str: ...
    def get_carid(self) -> str: ...
    def get_carlevel(self) -> PropertyCarlevel: ...
    def get_categories(self) -> str: ...
    def get_class(self) -> Property_Class: ...
    def get_cmd(self) -> PropertyCmd: ...
    def get_color(self) -> str: ...
    def get_comment(self) -> str: ...
    def get_completed(self) -> Time: ...
    def get_components(self) -> str: ...
    def get_contact(self) -> str: ...
    def get_created(self) -> Time: ...
    def get_csid(self) -> str: ...
    def get_datemax(self) -> Time: ...
    def get_datemin(self) -> Time: ...
    def get_datetime_with_component(
        self, comp: typing.Optional[Component] = None
    ) -> Time: ...
    def get_decreed(self) -> str: ...
    def get_defaultcharset(self) -> str: ...
    def get_defaultlocale(self) -> str: ...
    def get_defaulttzid(self) -> str: ...
    def get_defaultvcars(self) -> str: ...
    def get_deny(self) -> str: ...
    def get_description(self) -> str: ...
    def get_dtend(self) -> Time: ...
    def get_dtstamp(self) -> Time: ...
    def get_dtstart(self) -> Time: ...
    def get_due(self) -> Time: ...
    def get_duration(self) -> Duration: ...
    def get_estimatedduration(self) -> Duration: ...
    def get_exdate(self) -> Time: ...
    def get_expand(self) -> int: ...
    def get_exrule(self) -> Recurrence: ...
    def get_first_parameter(self, kind: ParameterKind) -> Parameter: ...
    def get_freebusy(self) -> Period: ...
    def get_geo(self) -> Geo: ...
    def get_grant(self) -> str: ...
    def get_itipversion(self) -> str: ...
    def get_lastmodified(self) -> Time: ...
    def get_location(self) -> str: ...
    def get_maxcomponentsize(self) -> int: ...
    def get_maxdate(self) -> Time: ...
    def get_maxresults(self) -> int: ...
    def get_maxresultssize(self) -> int: ...
    def get_method(self) -> PropertyMethod: ...
    def get_mindate(self) -> Time: ...
    def get_multipart(self) -> str: ...
    def get_name(self) -> str: ...
    def get_next_parameter(self, kind: ParameterKind) -> Parameter: ...
    def get_organizer(self) -> str: ...
    def get_owner(self) -> str: ...
    def get_parameter_as_string(self, name: str) -> str: ...
    def get_parent(self) -> typing.Optional[Component]: ...
    def get_percentcomplete(self) -> int: ...
    def get_permission(self) -> str: ...
    def get_pollcompletion(self) -> PropertyPollcompletion: ...
    def get_pollitemid(self) -> int: ...
    def get_pollmode(self) -> PropertyPollmode: ...
    def get_pollproperties(self) -> str: ...
    def get_pollwinner(self) -> int: ...
    def get_priority(self) -> int: ...
    def get_prodid(self) -> str: ...
    def get_property_name(self) -> str: ...
    def get_query(self) -> str: ...
    def get_queryid(self) -> str: ...
    def get_querylevel(self) -> PropertyQuerylevel: ...
    def get_queryname(self) -> str: ...
    def get_rdate(self) -> Datetimeperiod: ...
    def get_recuraccepted(self) -> str: ...
    def get_recurexpand(self) -> str: ...
    def get_recurlimit(self) -> str: ...
    def get_recurrenceid(self) -> Time: ...
    def get_relatedto(self) -> str: ...
    def get_relcalid(self) -> str: ...
    def get_repeat(self) -> int: ...
    def get_replyurl(self) -> str: ...
    def get_requeststatus(self) -> Reqstat: ...
    def get_resources(self) -> str: ...
    def get_response(self) -> int: ...
    def get_restriction(self) -> str: ...
    def get_rrule(self) -> Recurrence: ...
    def get_scope(self) -> str: ...
    def get_sequence(self) -> int: ...
    def get_status(self) -> PropertyStatus: ...
    def get_storesexpanded(self) -> str: ...
    def get_summary(self) -> str: ...
    def get_target(self) -> str: ...
    def get_taskmode(self) -> PropertyTaskmode: ...
    def get_transp(self) -> PropertyTransp: ...
    def get_trigger(self) -> Trigger: ...
    def get_tzid(self) -> str: ...
    def get_tzidaliasof(self) -> str: ...
    def get_tzname(self) -> str: ...
    def get_tzoffsetfrom(self) -> int: ...
    def get_tzoffsetto(self) -> int: ...
    def get_tzuntil(self) -> Time: ...
    def get_tzurl(self) -> str: ...
    def get_uid(self) -> str: ...
    def get_url(self) -> str: ...
    def get_value(self) -> Value: ...
    def get_value_as_string(self) -> str: ...
    def get_version(self) -> str: ...
    def get_voter(self) -> str: ...
    def get_x(self) -> str: ...
    def get_x_name(self) -> typing.Optional[str]: ...
    def get_xlicclass(self) -> PropertyXlicclass: ...
    def get_xlicclustercount(self) -> str: ...
    def get_xlicerror(self) -> str: ...
    def get_xlicmimecharset(self) -> str: ...
    def get_xlicmimecid(self) -> str: ...
    def get_xlicmimecontenttype(self) -> str: ...
    def get_xlicmimeencoding(self) -> str: ...
    def get_xlicmimefilename(self) -> str: ...
    def get_xlicmimeoptinfo(self) -> str: ...
    def isa(self) -> PropertyKind: ...
    def isa_property(self) -> int: ...
    @staticmethod
    def kind_and_string_to_enum(kind: int, str: str) -> int: ...
    @staticmethod
    def kind_from_string(string: str) -> PropertyKind: ...
    @staticmethod
    def kind_has_property(kind: PropertyKind, e: int) -> int: ...
    @staticmethod
    def kind_is_valid(kind: PropertyKind) -> bool: ...
    @staticmethod
    def kind_to_string(kind: PropertyKind) -> str: ...
    @staticmethod
    def kind_to_value_kind(kind: PropertyKind) -> ValueKind: ...
    @staticmethod
    def method_from_string(str: str) -> PropertyMethod: ...
    @staticmethod
    def method_to_string(method: PropertyMethod) -> str: ...
    @classmethod
    def new(cls, kind: PropertyKind) -> Property: ...
    @classmethod
    def new_acceptresponse(cls, v: str) -> Property: ...
    @classmethod
    def new_acknowledged(cls, v: Time) -> Property: ...
    @classmethod
    def new_action(cls, v: PropertyAction) -> Property: ...
    @classmethod
    def new_allowconflict(cls, v: str) -> Property: ...
    @classmethod
    def new_attach(cls, v: Attach) -> Property: ...
    @classmethod
    def new_attendee(cls, v: str) -> Property: ...
    @classmethod
    def new_busytype(cls, v: PropertyBusytype) -> Property: ...
    @classmethod
    def new_calid(cls, v: str) -> Property: ...
    @classmethod
    def new_calmaster(cls, v: str) -> Property: ...
    @classmethod
    def new_calscale(cls, v: str) -> Property: ...
    @classmethod
    def new_capversion(cls, v: str) -> Property: ...
    @classmethod
    def new_carid(cls, v: str) -> Property: ...
    @classmethod
    def new_carlevel(cls, v: PropertyCarlevel) -> Property: ...
    @classmethod
    def new_categories(cls, v: str) -> Property: ...
    @classmethod
    def new_class(cls, v: Property_Class) -> Property: ...
    @classmethod
    def new_cmd(cls, v: PropertyCmd) -> Property: ...
    @classmethod
    def new_color(cls, v: str) -> Property: ...
    @classmethod
    def new_comment(cls, v: str) -> Property: ...
    @classmethod
    def new_completed(cls, v: Time) -> Property: ...
    @classmethod
    def new_components(cls, v: str) -> Property: ...
    @classmethod
    def new_contact(cls, v: str) -> Property: ...
    @classmethod
    def new_created(cls, v: Time) -> Property: ...
    @classmethod
    def new_csid(cls, v: str) -> Property: ...
    @classmethod
    def new_datemax(cls, v: Time) -> Property: ...
    @classmethod
    def new_datemin(cls, v: Time) -> Property: ...
    @classmethod
    def new_decreed(cls, v: str) -> Property: ...
    @classmethod
    def new_defaultcharset(cls, v: str) -> Property: ...
    @classmethod
    def new_defaultlocale(cls, v: str) -> Property: ...
    @classmethod
    def new_defaulttzid(cls, v: str) -> Property: ...
    @classmethod
    def new_defaultvcars(cls, v: str) -> Property: ...
    @classmethod
    def new_deny(cls, v: str) -> Property: ...
    @classmethod
    def new_description(cls, v: str) -> Property: ...
    @classmethod
    def new_dtend(cls, v: Time) -> Property: ...
    @classmethod
    def new_dtstamp(cls, v: Time) -> Property: ...
    @classmethod
    def new_dtstart(cls, v: Time) -> Property: ...
    @classmethod
    def new_due(cls, v: Time) -> Property: ...
    @classmethod
    def new_duration(cls, v: Duration) -> Property: ...
    @classmethod
    def new_estimatedduration(cls, v: Duration) -> Property: ...
    @classmethod
    def new_exdate(cls, v: Time) -> Property: ...
    @classmethod
    def new_expand(cls, v: int) -> Property: ...
    @classmethod
    def new_exrule(cls, v: Recurrence) -> Property: ...
    @classmethod
    def new_freebusy(cls, v: Period) -> Property: ...
    @classmethod
    def new_from_string(cls, str: str) -> Property: ...
    @classmethod
    def new_geo(cls, v: Geo) -> Property: ...
    @classmethod
    def new_grant(cls, v: str) -> Property: ...
    @classmethod
    def new_itipversion(cls, v: str) -> Property: ...
    @classmethod
    def new_lastmodified(cls, v: Time) -> Property: ...
    @classmethod
    def new_location(cls, v: str) -> Property: ...
    @classmethod
    def new_maxcomponentsize(cls, v: int) -> Property: ...
    @classmethod
    def new_maxdate(cls, v: Time) -> Property: ...
    @classmethod
    def new_maxresults(cls, v: int) -> Property: ...
    @classmethod
    def new_maxresultssize(cls, v: int) -> Property: ...
    @classmethod
    def new_method(cls, v: PropertyMethod) -> Property: ...
    @classmethod
    def new_mindate(cls, v: Time) -> Property: ...
    @classmethod
    def new_multipart(cls, v: str) -> Property: ...
    @classmethod
    def new_name(cls, v: str) -> Property: ...
    @classmethod
    def new_organizer(cls, v: str) -> Property: ...
    @classmethod
    def new_owner(cls, v: str) -> Property: ...
    @classmethod
    def new_percentcomplete(cls, v: int) -> Property: ...
    @classmethod
    def new_permission(cls, v: str) -> Property: ...
    @classmethod
    def new_pollcompletion(cls, v: PropertyPollcompletion) -> Property: ...
    @classmethod
    def new_pollitemid(cls, v: int) -> Property: ...
    @classmethod
    def new_pollmode(cls, v: PropertyPollmode) -> Property: ...
    @classmethod
    def new_pollproperties(cls, v: str) -> Property: ...
    @classmethod
    def new_pollwinner(cls, v: int) -> Property: ...
    @classmethod
    def new_priority(cls, v: int) -> Property: ...
    @classmethod
    def new_prodid(cls, v: str) -> Property: ...
    @classmethod
    def new_query(cls, v: str) -> Property: ...
    @classmethod
    def new_queryid(cls, v: str) -> Property: ...
    @classmethod
    def new_querylevel(cls, v: PropertyQuerylevel) -> Property: ...
    @classmethod
    def new_queryname(cls, v: str) -> Property: ...
    @classmethod
    def new_rdate(cls, v: Datetimeperiod) -> Property: ...
    @classmethod
    def new_recuraccepted(cls, v: str) -> Property: ...
    @classmethod
    def new_recurexpand(cls, v: str) -> Property: ...
    @classmethod
    def new_recurlimit(cls, v: str) -> Property: ...
    @classmethod
    def new_recurrenceid(cls, v: Time) -> Property: ...
    @classmethod
    def new_relatedto(cls, v: str) -> Property: ...
    @classmethod
    def new_relcalid(cls, v: str) -> Property: ...
    @classmethod
    def new_repeat(cls, v: int) -> Property: ...
    @classmethod
    def new_replyurl(cls, v: str) -> Property: ...
    @classmethod
    def new_requeststatus(cls, v: Reqstat) -> Property: ...
    @classmethod
    def new_resources(cls, v: str) -> Property: ...
    @classmethod
    def new_response(cls, v: int) -> Property: ...
    @classmethod
    def new_restriction(cls, v: str) -> Property: ...
    @classmethod
    def new_rrule(cls, v: Recurrence) -> Property: ...
    @classmethod
    def new_scope(cls, v: str) -> Property: ...
    @classmethod
    def new_sequence(cls, v: int) -> Property: ...
    @classmethod
    def new_status(cls, v: PropertyStatus) -> Property: ...
    @classmethod
    def new_storesexpanded(cls, v: str) -> Property: ...
    @classmethod
    def new_summary(cls, v: str) -> Property: ...
    @classmethod
    def new_target(cls, v: str) -> Property: ...
    @classmethod
    def new_taskmode(cls, v: PropertyTaskmode) -> Property: ...
    @classmethod
    def new_transp(cls, v: PropertyTransp) -> Property: ...
    @classmethod
    def new_trigger(cls, v: Trigger) -> Property: ...
    @classmethod
    def new_tzid(cls, v: str) -> Property: ...
    @classmethod
    def new_tzidaliasof(cls, v: str) -> Property: ...
    @classmethod
    def new_tzname(cls, v: str) -> Property: ...
    @classmethod
    def new_tzoffsetfrom(cls, v: int) -> Property: ...
    @classmethod
    def new_tzoffsetto(cls, v: int) -> Property: ...
    @classmethod
    def new_tzuntil(cls, v: Time) -> Property: ...
    @classmethod
    def new_tzurl(cls, v: str) -> Property: ...
    @classmethod
    def new_uid(cls, v: str) -> Property: ...
    @classmethod
    def new_url(cls, v: str) -> Property: ...
    @classmethod
    def new_version(cls, v: str) -> Property: ...
    @classmethod
    def new_voter(cls, v: str) -> Property: ...
    @classmethod
    def new_x(cls, v: str) -> Property: ...
    @classmethod
    def new_xlicclass(cls, v: PropertyXlicclass) -> Property: ...
    @classmethod
    def new_xlicclustercount(cls, v: str) -> Property: ...
    @classmethod
    def new_xlicerror(cls, v: str) -> Property: ...
    @classmethod
    def new_xlicmimecharset(cls, v: str) -> Property: ...
    @classmethod
    def new_xlicmimecid(cls, v: str) -> Property: ...
    @classmethod
    def new_xlicmimecontenttype(cls, v: str) -> Property: ...
    @classmethod
    def new_xlicmimeencoding(cls, v: str) -> Property: ...
    @classmethod
    def new_xlicmimefilename(cls, v: str) -> Property: ...
    @classmethod
    def new_xlicmimeoptinfo(cls, v: str) -> Property: ...
    @staticmethod
    def recurrence_is_excluded(
        comp: Component, dtstart: Time, recurtime: Time
    ) -> bool: ...
    def remove_parameter_by_kind(self, kind: ParameterKind) -> None: ...
    def remove_parameter_by_name(self, name: str) -> None: ...
    def remove_parameter_by_ref(self, param: Parameter) -> None: ...
    def set_acceptresponse(self, v: str) -> None: ...
    def set_acknowledged(self, v: Time) -> None: ...
    def set_action(self, v: PropertyAction) -> None: ...
    def set_allowconflict(self, v: str) -> None: ...
    def set_attach(self, v: Attach) -> None: ...
    def set_attendee(self, v: str) -> None: ...
    def set_busytype(self, v: PropertyBusytype) -> None: ...
    def set_calid(self, v: str) -> None: ...
    def set_calmaster(self, v: str) -> None: ...
    def set_calscale(self, v: str) -> None: ...
    def set_capversion(self, v: str) -> None: ...
    def set_carid(self, v: str) -> None: ...
    def set_carlevel(self, v: PropertyCarlevel) -> None: ...
    def set_categories(self, v: str) -> None: ...
    def set_class(self, v: Property_Class) -> None: ...
    def set_cmd(self, v: PropertyCmd) -> None: ...
    def set_color(self, v: str) -> None: ...
    def set_comment(self, v: str) -> None: ...
    def set_completed(self, v: Time) -> None: ...
    def set_components(self, v: str) -> None: ...
    def set_contact(self, v: str) -> None: ...
    def set_created(self, v: Time) -> None: ...
    def set_csid(self, v: str) -> None: ...
    def set_datemax(self, v: Time) -> None: ...
    def set_datemin(self, v: Time) -> None: ...
    def set_decreed(self, v: str) -> None: ...
    def set_defaultcharset(self, v: str) -> None: ...
    def set_defaultlocale(self, v: str) -> None: ...
    def set_defaulttzid(self, v: str) -> None: ...
    def set_defaultvcars(self, v: str) -> None: ...
    def set_deny(self, v: str) -> None: ...
    def set_description(self, v: str) -> None: ...
    def set_dtend(self, v: Time) -> None: ...
    def set_dtstamp(self, v: Time) -> None: ...
    def set_dtstart(self, v: Time) -> None: ...
    def set_due(self, v: Time) -> None: ...
    def set_duration(self, v: Duration) -> None: ...
    def set_estimatedduration(self, v: Duration) -> None: ...
    def set_exdate(self, v: Time) -> None: ...
    def set_expand(self, v: int) -> None: ...
    def set_exrule(self, v: Recurrence) -> None: ...
    def set_freebusy(self, v: Period) -> None: ...
    def set_geo(self, v: Geo) -> None: ...
    def set_grant(self, v: str) -> None: ...
    def set_itipversion(self, v: str) -> None: ...
    def set_lastmodified(self, v: Time) -> None: ...
    def set_location(self, v: str) -> None: ...
    def set_maxcomponentsize(self, v: int) -> None: ...
    def set_maxdate(self, v: Time) -> None: ...
    def set_maxresults(self, v: int) -> None: ...
    def set_maxresultssize(self, v: int) -> None: ...
    def set_method(self, v: PropertyMethod) -> None: ...
    def set_mindate(self, v: Time) -> None: ...
    def set_multipart(self, v: str) -> None: ...
    def set_name(self, v: str) -> None: ...
    def set_organizer(self, v: str) -> None: ...
    def set_owner(self, v: str) -> None: ...
    def set_parameter(self, parameter: Parameter) -> None: ...
    def set_parameter_from_string(self, name: str, value: str) -> None: ...
    def set_parent(self, component: typing.Optional[Component] = None) -> None: ...
    def set_percentcomplete(self, v: int) -> None: ...
    def set_permission(self, v: str) -> None: ...
    def set_pollcompletion(self, v: PropertyPollcompletion) -> None: ...
    def set_pollitemid(self, v: int) -> None: ...
    def set_pollmode(self, v: PropertyPollmode) -> None: ...
    def set_pollproperties(self, v: str) -> None: ...
    def set_pollwinner(self, v: int) -> None: ...
    def set_priority(self, v: int) -> None: ...
    def set_prodid(self, v: str) -> None: ...
    def set_query(self, v: str) -> None: ...
    def set_queryid(self, v: str) -> None: ...
    def set_querylevel(self, v: PropertyQuerylevel) -> None: ...
    def set_queryname(self, v: str) -> None: ...
    def set_rdate(self, v: Datetimeperiod) -> None: ...
    def set_recuraccepted(self, v: str) -> None: ...
    def set_recurexpand(self, v: str) -> None: ...
    def set_recurlimit(self, v: str) -> None: ...
    def set_recurrenceid(self, v: Time) -> None: ...
    def set_relatedto(self, v: str) -> None: ...
    def set_relcalid(self, v: str) -> None: ...
    def set_repeat(self, v: int) -> None: ...
    def set_replyurl(self, v: str) -> None: ...
    def set_requeststatus(self, v: Reqstat) -> None: ...
    def set_resources(self, v: str) -> None: ...
    def set_response(self, v: int) -> None: ...
    def set_restriction(self, v: str) -> None: ...
    def set_rrule(self, v: Recurrence) -> None: ...
    def set_scope(self, v: str) -> None: ...
    def set_sequence(self, v: int) -> None: ...
    def set_status(self, v: PropertyStatus) -> None: ...
    def set_storesexpanded(self, v: str) -> None: ...
    def set_summary(self, v: str) -> None: ...
    def set_target(self, v: str) -> None: ...
    def set_taskmode(self, v: PropertyTaskmode) -> None: ...
    def set_transp(self, v: PropertyTransp) -> None: ...
    def set_trigger(self, v: Trigger) -> None: ...
    def set_tzid(self, v: str) -> None: ...
    def set_tzidaliasof(self, v: str) -> None: ...
    def set_tzname(self, v: str) -> None: ...
    def set_tzoffsetfrom(self, v: int) -> None: ...
    def set_tzoffsetto(self, v: int) -> None: ...
    def set_tzuntil(self, v: Time) -> None: ...
    def set_tzurl(self, v: str) -> None: ...
    def set_uid(self, v: str) -> None: ...
    def set_url(self, v: str) -> None: ...
    def set_value(self, value: Value) -> None: ...
    def set_value_from_string(self, value: str, kind: str) -> None: ...
    def set_version(self, v: str) -> None: ...
    def set_voter(self, v: str) -> None: ...
    def set_x(self, v: str) -> None: ...
    def set_x_name(self, name: str) -> None: ...
    def set_xlicclass(self, v: PropertyXlicclass) -> None: ...
    def set_xlicclustercount(self, v: str) -> None: ...
    def set_xlicerror(self, v: str) -> None: ...
    def set_xlicmimecharset(self, v: str) -> None: ...
    def set_xlicmimecid(self, v: str) -> None: ...
    def set_xlicmimecontenttype(self, v: str) -> None: ...
    def set_xlicmimeencoding(self, v: str) -> None: ...
    def set_xlicmimefilename(self, v: str) -> None: ...
    def set_xlicmimeoptinfo(self, v: str) -> None: ...
    @staticmethod
    def status_from_string(str: str) -> PropertyStatus: ...
    @staticmethod
    def status_to_string(method: PropertyStatus) -> str: ...

class PropertyClass(GObject.GPointer):
    """
    :Constructors:

    ::

        PropertyClass()
    """

    parent: ObjectClass = ...

class RecurIterator(Object):
    """
    :Constructors:

    ::

        RecurIterator(**properties)
        new(rule:ICalGLib.Recurrence, dtstart:ICalGLib.Time) -> ICalGLib.RecurIterator

    Object ICalRecurIterator

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    @classmethod
    def new(cls, rule: Recurrence, dtstart: Time) -> RecurIterator: ...
    def next(self) -> Time: ...
    def set_start(self, start: Time) -> int: ...

class RecurIteratorClass(GObject.GPointer):
    """
    :Constructors:

    ::

        RecurIteratorClass()
    """

    parent: ObjectClass = ...

class Recurrence(Object):
    """
    :Constructors:

    ::

        Recurrence(**properties)
        new() -> ICalGLib.Recurrence
        new_from_string(str:str) -> ICalGLib.Recurrence

    Object ICalRecurrence

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def clear(self) -> None: ...
    @staticmethod
    def day_day_of_week(day: int) -> RecurrenceWeekday: ...
    @staticmethod
    def day_position(day: int) -> int: ...
    @staticmethod
    def frequency_from_string(str: str) -> RecurrenceFrequency: ...
    @staticmethod
    def frequency_to_string(kind: RecurrenceFrequency) -> str: ...
    def get_by_day(self, index: int) -> int: ...
    def get_by_day_array(self) -> list[int]: ...
    def get_by_hour(self, index: int) -> int: ...
    def get_by_hour_array(self) -> list[int]: ...
    def get_by_minute(self, index: int) -> int: ...
    def get_by_minute_array(self) -> list[int]: ...
    def get_by_month(self, index: int) -> int: ...
    def get_by_month_array(self) -> list[int]: ...
    def get_by_month_day(self, index: int) -> int: ...
    def get_by_month_day_array(self) -> list[int]: ...
    def get_by_second(self, index: int) -> int: ...
    def get_by_second_array(self) -> list[int]: ...
    def get_by_set_pos(self, index: int) -> int: ...
    def get_by_set_pos_array(self) -> list[int]: ...
    def get_by_week_no(self, index: int) -> int: ...
    def get_by_week_no_array(self) -> list[int]: ...
    def get_by_year_day(self, index: int) -> int: ...
    def get_by_year_day_array(self) -> list[int]: ...
    def get_count(self) -> int: ...
    def get_freq(self) -> RecurrenceFrequency: ...
    def get_interval(self) -> int: ...
    def get_until(self) -> Time: ...
    def get_week_start(self) -> RecurrenceWeekday: ...
    @staticmethod
    def month_is_leap(month: int) -> bool: ...
    @staticmethod
    def month_month(month: int) -> int: ...
    @classmethod
    def new(cls) -> Recurrence: ...
    @classmethod
    def new_from_string(cls, str: str) -> Recurrence: ...
    @staticmethod
    def rscale_is_supported() -> bool: ...
    @staticmethod
    def rscale_supported_calendars() -> Array: ...
    def set_by_day(self, index: int, value: int) -> None: ...
    def set_by_day_array(self, values: typing.Sequence[int]) -> None: ...
    def set_by_hour(self, index: int, value: int) -> None: ...
    def set_by_hour_array(self, values: typing.Sequence[int]) -> None: ...
    def set_by_minute(self, index: int, value: int) -> None: ...
    def set_by_minute_array(self, values: typing.Sequence[int]) -> None: ...
    def set_by_month(self, index: int, value: int) -> None: ...
    def set_by_month_array(self, values: typing.Sequence[int]) -> None: ...
    def set_by_month_day(self, index: int, value: int) -> None: ...
    def set_by_month_day_array(self, values: typing.Sequence[int]) -> None: ...
    def set_by_second(self, index: int, value: int) -> None: ...
    def set_by_second_array(self, values: typing.Sequence[int]) -> None: ...
    def set_by_set_pos(self, index: int, value: int) -> None: ...
    def set_by_set_pos_array(self, values: typing.Sequence[int]) -> None: ...
    def set_by_week_no(self, index: int, value: int) -> None: ...
    def set_by_week_no_array(self, values: typing.Sequence[int]) -> None: ...
    def set_by_year_day(self, index: int, value: int) -> None: ...
    def set_by_year_day_array(self, values: typing.Sequence[int]) -> None: ...
    def set_count(self, count: int) -> None: ...
    def set_freq(self, freq: RecurrenceFrequency) -> None: ...
    def set_interval(self, interval: int) -> None: ...
    def set_until(self, until: Time) -> None: ...
    def set_week_start(self, week_start: RecurrenceWeekday) -> None: ...
    @staticmethod
    def skip_from_string(str: str) -> RecurrenceSkip: ...
    @staticmethod
    def skip_to_string(kind: RecurrenceSkip) -> str: ...
    def to_string(self) -> str: ...
    @staticmethod
    def weekday_from_string(str: str) -> RecurrenceWeekday: ...
    @staticmethod
    def weekday_to_string(kind: RecurrenceWeekday) -> str: ...

class RecurrenceClass(GObject.GPointer):
    """
    :Constructors:

    ::

        RecurrenceClass()
    """

    parent: ObjectClass = ...

class Reqstat(Object):
    """
    :Constructors:

    ::

        Reqstat(**properties)
        new_from_string(str:str) -> ICalGLib.Reqstat

    Object ICalReqstat

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def get_code(self) -> RequestStatus: ...
    def get_debug(self) -> str: ...
    def get_desc(self) -> str: ...
    @classmethod
    def new_from_string(cls, str: str) -> Reqstat: ...
    def set_code(self, code: RequestStatus) -> None: ...
    def to_string(self) -> str: ...

class ReqstatClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ReqstatClass()
    """

    parent: ObjectClass = ...

class Time(Object):
    """
    :Constructors:

    ::

        Time(**properties)
        new() -> ICalGLib.Time
        new_current_with_zone(zone:ICalGLib.Timezone=None) -> ICalGLib.Time
        new_from_day_of_year(day:int, year:int) -> ICalGLib.Time
        new_from_string(str:str) -> ICalGLib.Time
        new_from_timet_with_zone(v:int, is_date:int, zone:ICalGLib.Timezone=None) -> ICalGLib.Time
        new_null_date() -> ICalGLib.Time
        new_null_time() -> ICalGLib.Time
        new_today() -> ICalGLib.Time

    Object ICalTime

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def add(self, d: Duration) -> Time: ...
    def adjust(self, days: int, hours: int, minutes: int, seconds: int) -> None: ...
    def as_ical_string(self) -> str: ...
    def as_timet(self) -> int: ...
    def as_timet_with_zone(self, zone: typing.Optional[Timezone] = None) -> int: ...
    def clone(self) -> Time: ...
    def compare(self, b: Time) -> int: ...
    def compare_date_only(self, b: Time) -> int: ...
    def compare_date_only_tz(
        self, b: Time, zone: typing.Optional[Timezone] = None
    ) -> int: ...
    def convert_timezone(
        self,
        from_zone: typing.Optional[Timezone] = None,
        to_zone: typing.Optional[Timezone] = None,
    ) -> None: ...
    def convert_to_zone(self, zone: typing.Optional[Timezone] = None) -> Time: ...
    def convert_to_zone_inplace(
        self, zone: typing.Optional[Timezone] = None
    ) -> None: ...
    def day_of_week(self) -> int: ...
    def day_of_year(self) -> int: ...
    @staticmethod
    def days_in_month(month: int, year: int) -> int: ...
    @staticmethod
    def days_in_year(year: int) -> int: ...
    @staticmethod
    def days_is_leap_year(year: int) -> bool: ...
    def get_date(self) -> typing.Tuple[int, int, int]: ...
    def get_day(self) -> int: ...
    def get_hour(self) -> int: ...
    def get_minute(self) -> int: ...
    def get_month(self) -> int: ...
    def get_second(self) -> int: ...
    def get_time(self) -> typing.Tuple[int, int, int]: ...
    def get_timezone(self) -> Timezone: ...
    def get_tzid(self) -> typing.Optional[str]: ...
    def get_year(self) -> int: ...
    def is_date(self) -> bool: ...
    def is_daylight(self) -> bool: ...
    def is_null_time(self) -> bool: ...
    def is_utc(self) -> bool: ...
    def is_valid_time(self) -> bool: ...
    @classmethod
    def new(cls) -> Time: ...
    @classmethod
    def new_current_with_zone(cls, zone: typing.Optional[Timezone] = None) -> Time: ...
    @classmethod
    def new_from_day_of_year(cls, day: int, year: int) -> Time: ...
    @classmethod
    def new_from_string(cls, str: str) -> Time: ...
    @classmethod
    def new_from_timet_with_zone(
        cls, v: int, is_date: int, zone: typing.Optional[Timezone] = None
    ) -> Time: ...
    @classmethod
    def new_null_date(cls) -> Time: ...
    @classmethod
    def new_null_time(cls) -> Time: ...
    @classmethod
    def new_today(cls) -> Time: ...
    def normalize(self) -> Time: ...
    def normalize_inplace(self) -> None: ...
    def set_date(self, year: int, month: int, day: int) -> None: ...
    def set_day(self, day: int) -> None: ...
    def set_hour(self, hour: int) -> None: ...
    def set_is_date(self, is_date: bool) -> None: ...
    def set_is_daylight(self, is_daylight: bool) -> None: ...
    def set_minute(self, minute: int) -> None: ...
    def set_month(self, month: int) -> None: ...
    def set_second(self, second: int) -> None: ...
    def set_time(self, hour: int, minute: int, second: int) -> None: ...
    def set_timezone(self, zone: typing.Optional[Timezone] = None) -> None: ...
    def set_year(self, year: int) -> None: ...
    def start_doy_week(self, fdow: int) -> int: ...
    def subtract(self, t2: Time) -> Duration: ...
    @staticmethod
    def timezone_expand_vtimezone(
        comp: Component, end_year: int, changes: Array
    ) -> None: ...
    def week_number(self) -> int: ...

class TimeClass(GObject.GPointer):
    """
    :Constructors:

    ::

        TimeClass()
    """

    parent: ObjectClass = ...

class TimeSpan(Object):
    """
    :Constructors:

    ::

        TimeSpan(**properties)
        new(dtstart:ICalGLib.Time, dtend:ICalGLib.Time, is_busy:int) -> ICalGLib.TimeSpan
        new_timet(start:int, end:int, is_busy:bool) -> ICalGLib.TimeSpan

    Object ICalTimeSpan

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def clone(self) -> TimeSpan: ...
    def contains(self, container: TimeSpan) -> int: ...
    def get_end(self) -> int: ...
    def get_is_busy(self) -> bool: ...
    def get_start(self) -> int: ...
    @classmethod
    def new(cls, dtstart: Time, dtend: Time, is_busy: int) -> TimeSpan: ...
    @classmethod
    def new_timet(cls, start: int, end: int, is_busy: bool) -> TimeSpan: ...
    def overlaps(self, s2: TimeSpan) -> int: ...
    def set_end(self, end: int) -> None: ...
    def set_is_busy(self, is_busy: bool) -> None: ...
    def set_start(self, start: int) -> None: ...

class TimeSpanClass(GObject.GPointer):
    """
    :Constructors:

    ::

        TimeSpanClass()
    """

    parent: ObjectClass = ...

class Timezone(Object):
    """
    :Constructors:

    ::

        Timezone(**properties)
        array_new() -> ICalGLib.Array
        new() -> ICalGLib.Timezone or None

    Object ICalTimezone

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    @staticmethod
    def array_append_from_vtimezone(timezones: Array, child: Component) -> None: ...
    @staticmethod
    def array_element_at(timezones: Array, index: int) -> Timezone: ...
    @classmethod
    def array_new(cls) -> Timezone: ...
    def copy(self) -> Timezone: ...
    def dump_changes(self, max_year: int, fp: None) -> int: ...
    @staticmethod
    def free_builtin_timezones() -> None: ...
    @staticmethod
    def free_zone_directory() -> None: ...
    @staticmethod
    def get_builtin_timezone(
        location: typing.Optional[str] = None,
    ) -> typing.Optional[Timezone]: ...
    @staticmethod
    def get_builtin_timezone_from_offset(
        offset: int, tzname: typing.Optional[str] = None
    ) -> Timezone: ...
    @staticmethod
    def get_builtin_timezone_from_tzid(
        tzid: typing.Optional[str] = None,
    ) -> Timezone: ...
    @staticmethod
    def get_builtin_timezones() -> Array: ...
    @staticmethod
    def get_builtin_tzdata() -> bool: ...
    def get_component(self) -> Component: ...
    def get_display_name(self) -> str: ...
    def get_latitude(self) -> float: ...
    def get_location(self) -> typing.Optional[str]: ...
    @staticmethod
    def get_location_from_vtimezone(component: Component) -> str: ...
    def get_longitude(self) -> float: ...
    def get_tzid(self) -> typing.Optional[str]: ...
    def get_tznames(self) -> typing.Optional[str]: ...
    @staticmethod
    def get_tznames_from_vtimezone(component: Component) -> str: ...
    def get_utc_offset(
        self, tt: typing.Optional[Time] = None
    ) -> typing.Tuple[int, int]: ...
    def get_utc_offset_of_utc_time(self, tt: Time) -> typing.Tuple[int, int]: ...
    @staticmethod
    def get_utc_timezone() -> Timezone: ...
    @staticmethod
    def get_zone_directory() -> str: ...
    @classmethod
    def new(cls) -> typing.Optional[Timezone]: ...
    @staticmethod
    def release_zone_tab() -> None: ...
    @staticmethod
    def set_builtin_tzdata(set: bool) -> None: ...
    def set_component(self, comp: Component) -> int: ...
    @staticmethod
    def set_tzid_prefix(new_prefix: str) -> None: ...
    @staticmethod
    def set_zone_directory(path: str) -> None: ...

class TimezoneClass(GObject.GPointer):
    """
    :Constructors:

    ::

        TimezoneClass()
    """

    parent: ObjectClass = ...

class Trigger(Object):
    """
    :Constructors:

    ::

        Trigger(**properties)
        new_from_int(reltime:int) -> ICalGLib.Trigger
        new_from_string(str:str) -> ICalGLib.Trigger

    Object ICalTrigger

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def get_duration(self) -> Duration: ...
    def get_time(self) -> Time: ...
    def is_bad_trigger(self) -> bool: ...
    def is_null_trigger(self) -> bool: ...
    @classmethod
    def new_from_int(cls, reltime: int) -> Trigger: ...
    @classmethod
    def new_from_string(cls, str: str) -> Trigger: ...
    def set_duration(self, duration: Duration) -> None: ...
    def set_time(self, time: Time) -> None: ...

class TriggerClass(GObject.GPointer):
    """
    :Constructors:

    ::

        TriggerClass()
    """

    parent: ObjectClass = ...

class Value(Object):
    """
    :Constructors:

    ::

        Value(**properties)
        new(kind:ICalGLib.ValueKind) -> ICalGLib.Value
        new_action(v:ICalGLib.PropertyAction) -> ICalGLib.Value
        new_attach(v:ICalGLib.Attach) -> ICalGLib.Value
        new_binary(v:str) -> ICalGLib.Value
        new_boolean(v:int) -> ICalGLib.Value
        new_busytype(v:ICalGLib.PropertyBusytype) -> ICalGLib.Value
        new_caladdress(v:str) -> ICalGLib.Value
        new_carlevel(v:ICalGLib.PropertyCarlevel) -> ICalGLib.Value
        new_class(v:ICalGLib.Property_Class) -> ICalGLib.Value
        new_cmd(v:ICalGLib.PropertyCmd) -> ICalGLib.Value
        new_date(v:ICalGLib.Time) -> ICalGLib.Value
        new_datetime(v:ICalGLib.Time) -> ICalGLib.Value
        new_datetimedate(v:ICalGLib.Time) -> ICalGLib.Value
        new_datetimeperiod(v:ICalGLib.Datetimeperiod) -> ICalGLib.Value
        new_duration(v:ICalGLib.Duration) -> ICalGLib.Value
        new_float(v:float) -> ICalGLib.Value
        new_from_string(kind:ICalGLib.ValueKind, str:str) -> ICalGLib.Value
        new_geo(v:ICalGLib.Geo) -> ICalGLib.Value
        new_integer(v:int) -> ICalGLib.Value
        new_method(v:ICalGLib.PropertyMethod) -> ICalGLib.Value
        new_period(v:ICalGLib.Period) -> ICalGLib.Value
        new_pollcompletion(v:ICalGLib.PropertyPollcompletion) -> ICalGLib.Value
        new_pollmode(v:ICalGLib.PropertyPollmode) -> ICalGLib.Value
        new_query(v:str) -> ICalGLib.Value
        new_querylevel(v:ICalGLib.PropertyQuerylevel) -> ICalGLib.Value
        new_recur(v:ICalGLib.Recurrence) -> ICalGLib.Value
        new_requeststatus(v:ICalGLib.Reqstat) -> ICalGLib.Value
        new_status(v:ICalGLib.PropertyStatus) -> ICalGLib.Value
        new_string(v:str) -> ICalGLib.Value
        new_taskmode(v:ICalGLib.PropertyTaskmode) -> ICalGLib.Value
        new_text(v:str) -> ICalGLib.Value
        new_transp(v:ICalGLib.PropertyTransp) -> ICalGLib.Value
        new_trigger(v:ICalGLib.Trigger) -> ICalGLib.Value
        new_uri(v:str) -> ICalGLib.Value
        new_utcoffset(v:int) -> ICalGLib.Value
        new_x(v:str) -> ICalGLib.Value
        new_xlicclass(v:ICalGLib.PropertyXlicclass) -> ICalGLib.Value

    Object ICalValue

    Properties from ICalObject:
      native -> gpointer: Native
        Native libical structure
      native-destroy-func -> gpointer: Native-Destroy-Func
        GDestroyNotify function to use to destroy the native libical structure
      is-global-memory -> gboolean: Is-Global-Memory
        Whether the native libical structure is from a global shared memory
      always-destroy -> gboolean: Always-Destroy
        Whether the native libical structure is freed even when the owner is set
      owner -> GObject: Owner
        The native libical structure owner

    Signals from GObject:
      notify (GParam)
    """
    class Props(Object.Props):
        always_destroy: bool
        is_global_memory: bool
        native: typing.Optional[None]
        native_destroy_func: typing.Optional[None]
        owner: GObject.Object

    props: Props = ...
    def __init__(
        self,
        always_destroy: bool = ...,
        is_global_memory: bool = ...,
        native: None = ...,
        native_destroy_func: None = ...,
        owner: GObject.Object = ...,
    ) -> None: ...
    def as_ical_string(self) -> str: ...
    def clone(self) -> Value: ...
    def compare(self, b: Value) -> ParameterXliccomparetype: ...
    @staticmethod
    def decode_ical_string(szText: str) -> typing.Optional[str]: ...
    @staticmethod
    def encode_ical_string(szText: str) -> typing.Optional[str]: ...
    def get_action(self) -> PropertyAction: ...
    def get_attach(self) -> typing.Optional[Attach]: ...
    def get_binary(self) -> typing.Optional[str]: ...
    def get_boolean(self) -> int: ...
    def get_busytype(self) -> PropertyBusytype: ...
    def get_caladdress(self) -> typing.Optional[str]: ...
    def get_carlevel(self) -> PropertyCarlevel: ...
    def get_class(self) -> Property_Class: ...
    def get_cmd(self) -> PropertyCmd: ...
    def get_date(self) -> typing.Optional[Time]: ...
    def get_datetime(self) -> typing.Optional[Time]: ...
    def get_datetimedate(self) -> typing.Optional[Time]: ...
    def get_datetimeperiod(self) -> typing.Optional[Datetimeperiod]: ...
    def get_duration(self) -> typing.Optional[Duration]: ...
    def get_float(self) -> float: ...
    def get_geo(self) -> typing.Optional[Geo]: ...
    def get_integer(self) -> int: ...
    def get_method(self) -> PropertyMethod: ...
    def get_parent(self) -> typing.Optional[Property]: ...
    def get_period(self) -> typing.Optional[Period]: ...
    def get_pollcompletion(self) -> PropertyPollcompletion: ...
    def get_pollmode(self) -> PropertyPollmode: ...
    def get_query(self) -> typing.Optional[str]: ...
    def get_querylevel(self) -> PropertyQuerylevel: ...
    def get_recur(self) -> typing.Optional[Recurrence]: ...
    def get_requeststatus(self) -> typing.Optional[Reqstat]: ...
    def get_status(self) -> PropertyStatus: ...
    def get_string(self) -> typing.Optional[str]: ...
    def get_taskmode(self) -> PropertyTaskmode: ...
    def get_text(self) -> typing.Optional[str]: ...
    def get_transp(self) -> PropertyTransp: ...
    def get_trigger(self) -> typing.Optional[Trigger]: ...
    def get_uri(self) -> typing.Optional[str]: ...
    def get_utcoffset(self) -> int: ...
    def get_x(self) -> typing.Optional[str]: ...
    def get_xlicclass(self) -> PropertyXlicclass: ...
    def is_valid(self) -> bool: ...
    def isa(self) -> ValueKind: ...
    def isa_value(self) -> int: ...
    @staticmethod
    def kind_from_string(str: str) -> ValueKind: ...
    @staticmethod
    def kind_is_valid(kind: ValueKind) -> bool: ...
    @staticmethod
    def kind_to_property_kind(kind: ValueKind) -> PropertyKind: ...
    @staticmethod
    def kind_to_string(kind: ValueKind) -> str: ...
    @classmethod
    def new(cls, kind: ValueKind) -> Value: ...
    @classmethod
    def new_action(cls, v: PropertyAction) -> Value: ...
    @classmethod
    def new_attach(cls, v: Attach) -> Value: ...
    @classmethod
    def new_binary(cls, v: str) -> Value: ...
    @classmethod
    def new_boolean(cls, v: int) -> Value: ...
    @classmethod
    def new_busytype(cls, v: PropertyBusytype) -> Value: ...
    @classmethod
    def new_caladdress(cls, v: str) -> Value: ...
    @classmethod
    def new_carlevel(cls, v: PropertyCarlevel) -> Value: ...
    @classmethod
    def new_class(cls, v: Property_Class) -> Value: ...
    @classmethod
    def new_cmd(cls, v: PropertyCmd) -> Value: ...
    @classmethod
    def new_date(cls, v: Time) -> Value: ...
    @classmethod
    def new_datetime(cls, v: Time) -> Value: ...
    @classmethod
    def new_datetimedate(cls, v: Time) -> Value: ...
    @classmethod
    def new_datetimeperiod(cls, v: Datetimeperiod) -> Value: ...
    @classmethod
    def new_duration(cls, v: Duration) -> Value: ...
    @classmethod
    def new_float(cls, v: float) -> Value: ...
    @classmethod
    def new_from_string(cls, kind: ValueKind, str: str) -> Value: ...
    @classmethod
    def new_geo(cls, v: Geo) -> Value: ...
    @classmethod
    def new_integer(cls, v: int) -> Value: ...
    @classmethod
    def new_method(cls, v: PropertyMethod) -> Value: ...
    @classmethod
    def new_period(cls, v: Period) -> Value: ...
    @classmethod
    def new_pollcompletion(cls, v: PropertyPollcompletion) -> Value: ...
    @classmethod
    def new_pollmode(cls, v: PropertyPollmode) -> Value: ...
    @classmethod
    def new_query(cls, v: str) -> Value: ...
    @classmethod
    def new_querylevel(cls, v: PropertyQuerylevel) -> Value: ...
    @classmethod
    def new_recur(cls, v: Recurrence) -> Value: ...
    @classmethod
    def new_requeststatus(cls, v: Reqstat) -> Value: ...
    @classmethod
    def new_status(cls, v: PropertyStatus) -> Value: ...
    @classmethod
    def new_string(cls, v: str) -> Value: ...
    @classmethod
    def new_taskmode(cls, v: PropertyTaskmode) -> Value: ...
    @classmethod
    def new_text(cls, v: str) -> Value: ...
    @classmethod
    def new_transp(cls, v: PropertyTransp) -> Value: ...
    @classmethod
    def new_trigger(cls, v: Trigger) -> Value: ...
    @classmethod
    def new_uri(cls, v: str) -> Value: ...
    @classmethod
    def new_utcoffset(cls, v: int) -> Value: ...
    @classmethod
    def new_x(cls, v: str) -> Value: ...
    @classmethod
    def new_xlicclass(cls, v: PropertyXlicclass) -> Value: ...
    def reset_kind(self) -> None: ...
    def set_action(self, v: PropertyAction) -> None: ...
    def set_attach(self, v: Attach) -> None: ...
    def set_binary(self, v: str) -> None: ...
    def set_boolean(self, v: int) -> None: ...
    def set_busytype(self, v: PropertyBusytype) -> None: ...
    def set_caladdress(self, v: str) -> None: ...
    def set_carlevel(self, v: PropertyCarlevel) -> None: ...
    def set_class(self, v: Property_Class) -> None: ...
    def set_cmd(self, v: PropertyCmd) -> None: ...
    def set_date(self, v: Time) -> None: ...
    def set_datetime(self, v: Time) -> None: ...
    def set_datetimedate(self, v: Time) -> None: ...
    def set_datetimeperiod(self, v: Datetimeperiod) -> None: ...
    def set_duration(self, v: Duration) -> None: ...
    def set_float(self, v: float) -> None: ...
    def set_geo(self, v: Geo) -> None: ...
    def set_integer(self, v: int) -> None: ...
    def set_method(self, v: PropertyMethod) -> None: ...
    def set_parent(self, property: typing.Optional[Property] = None) -> None: ...
    def set_period(self, v: Period) -> None: ...
    def set_pollcompletion(self, v: PropertyPollcompletion) -> None: ...
    def set_pollmode(self, v: PropertyPollmode) -> None: ...
    def set_query(self, v: str) -> None: ...
    def set_querylevel(self, v: PropertyQuerylevel) -> None: ...
    def set_recur(self, v: Recurrence) -> None: ...
    def set_requeststatus(self, v: Reqstat) -> None: ...
    def set_status(self, v: PropertyStatus) -> None: ...
    def set_string(self, v: str) -> None: ...
    def set_taskmode(self, v: PropertyTaskmode) -> None: ...
    def set_text(self, v: str) -> None: ...
    def set_transp(self, v: PropertyTransp) -> None: ...
    def set_trigger(self, v: Trigger) -> None: ...
    def set_uri(self, v: str) -> None: ...
    def set_utcoffset(self, v: int) -> None: ...
    def set_x(self, v: str) -> None: ...
    def set_xlicclass(self, v: PropertyXlicclass) -> None: ...

class ValueClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ValueClass()
    """

    parent: ObjectClass = ...

class _Array(GObject.GPointer):
    """
    :Constructors:

    ::

        _Array()
    """

    parent: Object = ...

class _Attach(GObject.GPointer):
    """
    :Constructors:

    ::

        _Attach()
    """

    parent: Object = ...

class _CompIter(GObject.GPointer):
    """
    :Constructors:

    ::

        _CompIter()
    """

    parent: Object = ...

class _Component(GObject.GPointer):
    """
    :Constructors:

    ::

        _Component()
    """

    parent: Object = ...

class _Datetimeperiod(GObject.GPointer):
    """
    :Constructors:

    ::

        _Datetimeperiod()
    """

    parent: Object = ...

class _Duration(GObject.GPointer):
    """
    :Constructors:

    ::

        _Duration()
    """

    parent: Object = ...

class _Geo(GObject.GPointer):
    """
    :Constructors:

    ::

        _Geo()
    """

    parent: Object = ...

class _Parameter(GObject.GPointer):
    """
    :Constructors:

    ::

        _Parameter()
    """

    parent: Object = ...

class _Parser(GObject.GPointer):
    """
    :Constructors:

    ::

        _Parser()
    """

    parent: Object = ...

class _Period(GObject.GPointer):
    """
    :Constructors:

    ::

        _Period()
    """

    parent: Object = ...

class _Property(GObject.GPointer):
    """
    :Constructors:

    ::

        _Property()
    """

    parent: Object = ...

class _RecurIterator(GObject.GPointer):
    """
    :Constructors:

    ::

        _RecurIterator()
    """

    parent: Object = ...

class _Recurrence(GObject.GPointer):
    """
    :Constructors:

    ::

        _Recurrence()
    """

    parent: Object = ...

class _Reqstat(GObject.GPointer):
    """
    :Constructors:

    ::

        _Reqstat()
    """

    parent: Object = ...

class _Time(GObject.GPointer):
    """
    :Constructors:

    ::

        _Time()
    """

    parent: Object = ...

class _TimeSpan(GObject.GPointer):
    """
    :Constructors:

    ::

        _TimeSpan()
    """

    parent: Object = ...

class _Timezone(GObject.GPointer):
    """
    :Constructors:

    ::

        _Timezone()
    """

    parent: Object = ...

class _Trigger(GObject.GPointer):
    """
    :Constructors:

    ::

        _Trigger()
    """

    parent: Object = ...

class _Value(GObject.GPointer):
    """
    :Constructors:

    ::

        _Value()
    """

    parent: Object = ...

class ComponentKind(GObject.GEnum):
    ANY_COMPONENT = 1
    NO_COMPONENT = 0
    VAGENDA_COMPONENT = 8
    VALARM_COMPONENT = 10
    VAVAILABILITY_COMPONENT = 26
    VCALENDAR_COMPONENT = 7
    VCAR_COMPONENT = 22
    VCOMMAND_COMPONENT = 23
    VEVENT_COMPONENT = 4
    VFREEBUSY_COMPONENT = 9
    VJOURNAL_COMPONENT = 6
    VPOLL_COMPONENT = 28
    VQUERY_COMPONENT = 20
    VREPLY_COMPONENT = 21
    VSCHEDULE_COMPONENT = 19
    VTIMEZONE_COMPONENT = 15
    VTODO_COMPONENT = 5
    VVOTER_COMPONENT = 29
    XATTACH_COMPONENT = 3
    XAUDIOALARM_COMPONENT = 11
    XAVAILABLE_COMPONENT = 27
    XDAYLIGHT_COMPONENT = 17
    XDISPLAYALARM_COMPONENT = 12
    XEMAILALARM_COMPONENT = 13
    XLICINVALID_COMPONENT = 24
    XLICMIMEPART_COMPONENT = 25
    XPROCEDUREALARM_COMPONENT = 14
    XROOT_COMPONENT = 2
    XSTANDARD_COMPONENT = 16
    XVOTE_COMPONENT = 30
    X_COMPONENT = 18

class ErrorEnum(GObject.GEnum):
    ALLOCATION_ERROR = 3
    BADARG_ERROR = 1
    FILE_ERROR = 7
    INTERNAL_ERROR = 6
    MALFORMEDDATA_ERROR = 4
    NEWFAILED_ERROR = 2
    NO_ERROR = 0
    PARSE_ERROR = 5
    UNIMPLEMENTED_ERROR = 9
    UNKNOWN_ERROR = 10
    USAGE_ERROR = 8

class ErrorState(GObject.GEnum):
    DEFAULT = 2
    FATAL = 0
    NONFATAL = 1
    UNKNOWN = 3

class ParameterAction(GObject.GEnum):
    ABORT = 20002
    ASK = 20001
    NONE = 20099
    X = 20000

class ParameterCutype(GObject.GEnum):
    GROUP = 20102
    INDIVIDUAL = 20101
    NONE = 20199
    RESOURCE = 20103
    ROOM = 20104
    UNKNOWN = 20105
    X = 20100

class ParameterDisplay(GObject.GEnum):
    BADGE = 22001
    FULLSIZE = 22003
    GRAPHIC = 22002
    NONE = 22099
    THUMBNAIL = 22004
    X = 22000

class ParameterEnable(GObject.GEnum):
    FALSE = 20202
    NONE = 20299
    TRUE = 20201
    X = 20200

class ParameterEncoding(GObject.GEnum):
    BASE64 = 20302
    NONE = 20399
    X = 20300

class ParameterFbtype(GObject.GEnum):
    BUSY = 20402
    BUSYTENTATIVE = 20404
    BUSYUNAVAILABLE = 20403
    FREE = 20401
    NONE = 20499
    X = 20400

class ParameterFeature(GObject.GEnum):
    AUDIO = 22101
    CHAT = 22102
    FEED = 22103
    MODERATOR = 22104
    NONE = 22199
    PHONE = 22105
    SCREEN = 22106
    VIDEO = 22107
    X = 22100

class ParameterKind(GObject.GEnum):
    ACTIONPARAM_PARAMETER = 1
    ALTREP_PARAMETER = 2
    ANY_PARAMETER = 0
    CHARSET_PARAMETER = 3
    CN_PARAMETER = 4
    CUTYPE_PARAMETER = 5
    DELEGATEDFROM_PARAMETER = 6
    DELEGATEDTO_PARAMETER = 7
    DIR_PARAMETER = 8
    DISPLAY_PARAMETER = 46
    EMAIL_PARAMETER = 50
    ENABLE_PARAMETER = 9
    ENCODING_PARAMETER = 10
    FBTYPE_PARAMETER = 11
    FEATURE_PARAMETER = 48
    FILENAME_PARAMETER = 42
    FMTTYPE_PARAMETER = 12
    IANA_PARAMETER = 33
    ID_PARAMETER = 13
    LABEL_PARAMETER = 49
    LANGUAGE_PARAMETER = 14
    LATENCY_PARAMETER = 15
    LOCALIZE_PARAMETER = 17
    LOCAL_PARAMETER = 16
    MANAGEDID_PARAMETER = 40
    MEMBER_PARAMETER = 18
    MODIFIED_PARAMETER = 44
    NO_PARAMETER = 32
    OPTIONS_PARAMETER = 19
    PARTSTAT_PARAMETER = 20
    PATCHACTION_PARAMETER = 51
    PUBLICCOMMENT_PARAMETER = 37
    RANGE_PARAMETER = 21
    REASON_PARAMETER = 43
    RELATED_PARAMETER = 22
    RELTYPE_PARAMETER = 23
    REQUIRED_PARAMETER = 43
    RESPONSE_PARAMETER = 38
    ROLE_PARAMETER = 24
    RSVP_PARAMETER = 25
    SCHEDULEAGENT_PARAMETER = 34
    SCHEDULEFORCESEND_PARAMETER = 35
    SCHEDULESTATUS_PARAMETER = 36
    SENTBY_PARAMETER = 26
    SIZE_PARAMETER = 41
    STAYINFORMED_PARAMETER = 39
    SUBSTATE_PARAMETER = 45
    TZID_PARAMETER = 27
    VALUE_PARAMETER = 28
    XLICCOMPARETYPE_PARAMETER = 30
    XLICERRORTYPE_PARAMETER = 31
    X_PARAMETER = 29

class ParameterLocal(GObject.GEnum):
    FALSE = 20502
    NONE = 20599
    TRUE = 20501
    X = 20500

class ParameterPartstat(GObject.GEnum):
    ACCEPTED = 20602
    COMPLETED = 20606
    DECLINED = 20603
    DELEGATED = 20605
    FAILED = 20608
    INPROCESS = 20607
    NEEDSACTION = 20601
    NONE = 20699
    TENTATIVE = 20604
    X = 20600

class ParameterPatchaction(GObject.GEnum):
    BYNAME = 22202
    BYPARAM = 22204
    BYVALUE = 22203
    CREATE = 22201
    NONE = 22299
    X = 22200

class ParameterRange(GObject.GEnum):
    NONE = 20799
    THISANDFUTURE = 20702
    THISANDPRIOR = 20701
    X = 20700

class ParameterRelated(GObject.GEnum):
    END = 20802
    NONE = 20899
    START = 20801
    X = 20800

class ParameterReltype(GObject.GEnum):
    CHILD = 20902
    NONE = 20999
    PARENT = 20901
    POLL = 20904
    SIBLING = 20903
    X = 20900

class ParameterRequired(GObject.GEnum):
    FALSE = 21002
    NONE = 21099
    TRUE = 21001
    X = 21000

class ParameterRole(GObject.GEnum):
    CHAIR = 21101
    NONE = 21199
    NONPARTICIPANT = 21104
    OPTPARTICIPANT = 21103
    REQPARTICIPANT = 21102
    X = 21100

class ParameterRsvp(GObject.GEnum):
    FALSE = 21202
    NONE = 21299
    TRUE = 21201
    X = 21200

class ParameterScheduleagent(GObject.GEnum):
    CLIENT = 21302
    NONE = 21399
    SERVER = 21301
    X = 21300

class ParameterScheduleforcesend(GObject.GEnum):
    NONE = 21499
    REPLY = 21402
    REQUEST = 21401
    X = 21400

class ParameterStayinformed(GObject.GEnum):
    FALSE = 21502
    NONE = 21599
    TRUE = 21501
    X = 21500

class ParameterSubstate(GObject.GEnum):
    ERROR = 21902
    NONE = 21999
    OK = 21901
    SUSPENDED = 21903
    X = 21900

class ParameterValue(GObject.GEnum):
    BINARY = 21601
    BOOLEAN = 21602
    CALADDRESS = 21614
    DATE = 21603
    DATETIME = 21612
    DURATION = 21604
    ERROR = 21611
    FLOAT = 21605
    INTEGER = 21606
    NONE = 21699
    PERIOD = 21607
    RECUR = 21608
    TEXT = 21609
    URI = 21610
    UTCOFFSET = 21613
    X = 21600

class ParameterXliccomparetype(GObject.GEnum):
    EQUAL = 21701
    GREATER = 21704
    GREATEREQUAL = 21706
    ISNOTNULL = 21709
    ISNULL = 21708
    LESS = 21703
    LESSEQUAL = 21705
    NONE = 21799
    NOTEQUAL = 21702
    REGEX = 21707
    X = 21700

class ParameterXlicerrortype(GObject.GEnum):
    COMPONENTPARSEERROR = 21801
    INVALIDITIP = 21806
    MIMEPARSEERROR = 21808
    NONE = 21899
    PARAMETERNAMEPARSEERROR = 21803
    PARAMETERVALUEPARSEERROR = 21804
    PROPERTYPARSEERROR = 21802
    UNKNOWNVCALPROPERROR = 21807
    VALUEPARSEERROR = 21805
    VCALPROPPARSEERROR = 21809
    X = 21800

class ParserState(GObject.GEnum):
    BEGIN_COMP = 2
    END_COMP = 3
    ERROR = 0
    IN_PROGRESS = 4
    SUCCESS = 1

class PropertyAction(GObject.GEnum):
    AUDIO = 10001
    DISPLAY = 10002
    EMAIL = 10003
    NONE = 10099
    PROCEDURE = 10004
    X = 10000

class PropertyBusytype(GObject.GEnum):
    BUSY = 10101
    BUSYTENTATIVE = 10103
    BUSYUNAVAILABLE = 10102
    NONE = 10199
    X = 10100

class PropertyCarlevel(GObject.GEnum):
    CARFULL1 = 10203
    CARMIN = 10202
    CARNONE = 10201
    NONE = 10299
    X = 10200

class PropertyCmd(GObject.GEnum):
    ABORT = 10401
    CONTINUE = 10402
    CREATE = 10403
    DELETE = 10404
    GENERATEUID = 10405
    GETCAPABILITY = 10406
    IDENTIFY = 10407
    MODIFY = 10408
    MOVE = 10409
    NONE = 10499
    REPLY = 10410
    SEARCH = 10411
    SETLOCALE = 10412
    X = 10400

class PropertyKind(GObject.GEnum):
    ACCEPTRESPONSE_PROPERTY = 102
    ACKNOWLEDGED_PROPERTY = 1
    ACTION_PROPERTY = 2
    ALLOWCONFLICT_PROPERTY = 3
    ANY_PROPERTY = 0
    ATTACH_PROPERTY = 4
    ATTENDEE_PROPERTY = 5
    BUSYTYPE_PROPERTY = 101
    CALID_PROPERTY = 6
    CALMASTER_PROPERTY = 7
    CALSCALE_PROPERTY = 8
    CAPVERSION_PROPERTY = 9
    CARID_PROPERTY = 11
    CARLEVEL_PROPERTY = 10
    CATEGORIES_PROPERTY = 12
    CLASS_PROPERTY = 13
    CMD_PROPERTY = 14
    COLOR_PROPERTY = 118
    COMMENT_PROPERTY = 15
    COMPLETED_PROPERTY = 16
    COMPONENTS_PROPERTY = 17
    CONTACT_PROPERTY = 18
    CREATED_PROPERTY = 19
    CSID_PROPERTY = 20
    DATEMAX_PROPERTY = 21
    DATEMIN_PROPERTY = 22
    DECREED_PROPERTY = 23
    DEFAULTCHARSET_PROPERTY = 24
    DEFAULTLOCALE_PROPERTY = 25
    DEFAULTTZID_PROPERTY = 26
    DEFAULTVCARS_PROPERTY = 27
    DENY_PROPERTY = 28
    DESCRIPTION_PROPERTY = 29
    DTEND_PROPERTY = 30
    DTSTAMP_PROPERTY = 31
    DTSTART_PROPERTY = 32
    DUE_PROPERTY = 33
    DURATION_PROPERTY = 34
    ESTIMATEDDURATION_PROPERTY = 113
    EXDATE_PROPERTY = 35
    EXPAND_PROPERTY = 36
    EXRULE_PROPERTY = 37
    FREEBUSY_PROPERTY = 38
    GEO_PROPERTY = 39
    GRANT_PROPERTY = 40
    ITIPVERSION_PROPERTY = 41
    LASTMODIFIED_PROPERTY = 42
    LOCATION_PROPERTY = 43
    MAXCOMPONENTSIZE_PROPERTY = 44
    MAXDATE_PROPERTY = 45
    MAXRESULTSSIZE_PROPERTY = 47
    MAXRESULTS_PROPERTY = 46
    METHOD_PROPERTY = 48
    MINDATE_PROPERTY = 49
    MULTIPART_PROPERTY = 50
    NAME_PROPERTY = 115
    NO_PROPERTY = 100
    ORGANIZER_PROPERTY = 52
    OWNER_PROPERTY = 53
    PERCENTCOMPLETE_PROPERTY = 54
    PERMISSION_PROPERTY = 55
    POLLCOMPLETION_PROPERTY = 110
    POLLITEMID_PROPERTY = 103
    POLLMODE_PROPERTY = 104
    POLLPROPERTIES_PROPERTY = 105
    POLLWINNER_PROPERTY = 106
    PRIORITY_PROPERTY = 56
    PRODID_PROPERTY = 57
    QUERYID_PROPERTY = 60
    QUERYLEVEL_PROPERTY = 59
    QUERYNAME_PROPERTY = 61
    QUERY_PROPERTY = 58
    RDATE_PROPERTY = 62
    RECURACCEPTED_PROPERTY = 63
    RECUREXPAND_PROPERTY = 64
    RECURLIMIT_PROPERTY = 65
    RECURRENCEID_PROPERTY = 66
    RELATEDTO_PROPERTY = 67
    RELCALID_PROPERTY = 68
    REPEAT_PROPERTY = 69
    REPLYURL_PROPERTY = 111
    REQUESTSTATUS_PROPERTY = 70
    RESOURCES_PROPERTY = 71
    RESPONSE_PROPERTY = 112
    RESTRICTION_PROPERTY = 72
    RRULE_PROPERTY = 73
    SCOPE_PROPERTY = 74
    SEQUENCE_PROPERTY = 75
    STATUS_PROPERTY = 76
    STORESEXPANDED_PROPERTY = 77
    SUMMARY_PROPERTY = 78
    TARGET_PROPERTY = 79
    TASKMODE_PROPERTY = 114
    TRANSP_PROPERTY = 80
    TRIGGER_PROPERTY = 81
    TZIDALIASOF_PROPERTY = 108
    TZID_PROPERTY = 82
    TZNAME_PROPERTY = 83
    TZOFFSETFROM_PROPERTY = 84
    TZOFFSETTO_PROPERTY = 85
    TZUNTIL_PROPERTY = 109
    TZURL_PROPERTY = 86
    UID_PROPERTY = 87
    URL_PROPERTY = 88
    VERSION_PROPERTY = 89
    VOTER_PROPERTY = 107
    XLICCLASS_PROPERTY = 91
    XLICCLUSTERCOUNT_PROPERTY = 92
    XLICERROR_PROPERTY = 93
    XLICMIMECHARSET_PROPERTY = 94
    XLICMIMECID_PROPERTY = 95
    XLICMIMECONTENTTYPE_PROPERTY = 96
    XLICMIMEENCODING_PROPERTY = 97
    XLICMIMEFILENAME_PROPERTY = 98
    XLICMIMEOPTINFO_PROPERTY = 99
    X_PROPERTY = 90

class PropertyMethod(GObject.GEnum):
    ADD = 10504
    CANCEL = 10505
    COUNTER = 10507
    CREATE = 10509
    DECLINECOUNTER = 10508
    DELETE = 10515
    GENERATEUID = 10514
    MODIFY = 10513
    MOVE = 10512
    NONE = 10599
    PUBLISH = 10501
    READ = 10510
    REFRESH = 10506
    REPLY = 10503
    REQUEST = 10502
    RESPONSE = 10511
    X = 10500

class PropertyPollcompletion(GObject.GEnum):
    CLIENT = 10604
    NONE = 10699
    SERVER = 10601
    SERVERCHOICE = 10603
    SERVERSUBMIT = 10602
    X = 10600

class PropertyPollmode(GObject.GEnum):
    BASIC = 10701
    NONE = 10799
    X = 10700

class PropertyQuerylevel(GObject.GEnum):
    CALQL1 = 10801
    CALQLNONE = 10802
    NONE = 10899
    X = 10800

class PropertyStatus(GObject.GEnum):
    CANCELLED = 10905
    COMPLETED = 10903
    CONFIRMED = 10902
    DELETED = 10912
    DRAFT = 10907
    FAILED = 10911
    FINAL = 10908
    INPROCESS = 10906
    NEEDSACTION = 10904
    NONE = 10999
    PENDING = 10910
    SUBMITTED = 10909
    TENTATIVE = 10901
    X = 10900

class PropertyTaskmode(GObject.GEnum):
    AUTOMATICCOMPLETION = 11201
    AUTOMATICFAILURE = 11202
    AUTOMATICSTATUS = 11203
    NONE = 11299
    X = 11200

class PropertyTransp(GObject.GEnum):
    NONE = 11099
    OPAQUE = 11001
    OPAQUENOCONFLICT = 11002
    TRANSPARENT = 11003
    TRANSPARENTNOCONFLICT = 11004
    X = 11000

class PropertyXlicclass(GObject.GEnum):
    ADDINSTANCE = 11117
    CANCELALL = 11120
    CANCELEVENT = 11118
    CANCELINSTANCE = 11119
    COUNTER = 11122
    DECLINECOUNTER = 11123
    MALFORMED = 11124
    MISSEQUENCED = 11126
    NONE = 11199
    OBSOLETE = 11125
    PUBLISHFREEBUSY = 11103
    PUBLISHNEW = 11101
    PUBLISHUPDATE = 11102
    REFRESH = 11121
    REPLYACCEPT = 11112
    REPLYCRASHERACCEPT = 11115
    REPLYCRASHERDECLINE = 11116
    REPLYDECLINE = 11113
    REPLYDELEGATE = 11114
    REQUESTDELEGATE = 11107
    REQUESTFORWARD = 11109
    REQUESTFREEBUSY = 11111
    REQUESTNEW = 11104
    REQUESTNEWORGANIZER = 11108
    REQUESTRESCHEDULE = 11106
    REQUESTSTATUS = 11110
    REQUESTUPDATE = 11105
    UNKNOWN = 11127
    X = 11100

class Property_Class(GObject.GEnum):
    CONFIDENTIAL = 10303
    NONE = 10399
    PRIVATE = 10302
    PUBLIC = 10301
    X = 10300

class RecurrenceArrayMaxValues(GObject.GEnum):
    RECURRENCE_ARRAY_MAX = 32639

class RecurrenceArraySizes(GObject.GEnum):
    DAY_SIZE = 386
    HOUR_SIZE = 25
    MINUTE_SIZE = 61
    MONTHDAY_SIZE = 32
    MONTH_SIZE = 14
    SECOND_SIZE = 62
    SETPOS_SIZE = 386
    WEEKNO_SIZE = 56
    YEARDAY_SIZE = 386

class RecurrenceFrequency(GObject.GEnum):
    DAILY_RECURRENCE = 3
    HOURLY_RECURRENCE = 2
    MINUTELY_RECURRENCE = 1
    MONTHLY_RECURRENCE = 5
    NO_RECURRENCE = 7
    SECONDLY_RECURRENCE = 0
    WEEKLY_RECURRENCE = 4
    YEARLY_RECURRENCE = 6

class RecurrenceSkip(GObject.GEnum):
    BACKWARD = 0
    FORWARD = 1
    OMIT = 2
    UNDEFINED = 3

class RecurrenceWeekday(GObject.GEnum):
    FRIDAY_WEEKDAY = 6
    MONDAY_WEEKDAY = 2
    NO_WEEKDAY = 0
    SATURDAY_WEEKDAY = 7
    SUNDAY_WEEKDAY = 1
    THURSDAY_WEEKDAY = 5
    TUESDAY_WEEKDAY = 3
    WEDNESDAY_WEEKDAY = 4

class RequestStatus(GObject.GEnum):
    UNKNOWN_STATUS = 0

class RestrictionKind(GObject.GEnum):
    NONE = 0
    ONE = 2
    ONEEXCLUSIVE = 6
    ONEMUTUAL = 7
    ONEPLUS = 4
    UNKNOWN = 8
    ZERO = 1
    ZEROORONE = 5
    ZEROPLUS = 3

class Unknowntokenhandling(GObject.GEnum):
    ASSUME_IANA_TOKEN = 1
    DISCARD_TOKEN = 2
    TREAT_AS_ERROR = 3

class ValueKind(GObject.GEnum):
    ACTION_VALUE = 5027
    ANY_VALUE = 5000
    ATTACH_VALUE = 5003
    BINARY_VALUE = 5011
    BOOLEAN_VALUE = 5021
    BUSYTYPE_VALUE = 5032
    CALADDRESS_VALUE = 5023
    CARLEVEL_VALUE = 5016
    CLASS_VALUE = 5019
    CMD_VALUE = 5010
    DATETIMEDATE_VALUE = 5036
    DATETIMEPERIOD_VALUE = 5015
    DATETIME_VALUE = 5028
    DATE_VALUE = 5002
    DURATION_VALUE = 5020
    FLOAT_VALUE = 5013
    GEO_VALUE = 5004
    INTEGER_VALUE = 5017
    METHOD_VALUE = 5030
    NO_VALUE = 5031
    PERIOD_VALUE = 5014
    POLLCOMPLETION_VALUE = 5034
    POLLMODE_VALUE = 5033
    QUERYLEVEL_VALUE = 5012
    QUERY_VALUE = 5001
    RECUR_VALUE = 5026
    REQUESTSTATUS_VALUE = 5009
    STATUS_VALUE = 5005
    STRING_VALUE = 5007
    TASKMODE_VALUE = 5035
    TEXT_VALUE = 5008
    TRANSP_VALUE = 5006
    TRIGGER_VALUE = 5024
    URI_VALUE = 5018
    UTCOFFSET_VALUE = 5029
    XLICCLASS_VALUE = 5025
    X_VALUE = 5022
